from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class Pdf3DNodeCollection(SpireObject):
    """
    Represents a collection of objects.
    """

    def Add(self, value: 'Pdf3DNode') -> int:
        """
        Adds the specified value.

        Args:
            value: The value to add.

        Returns:
            The result of the addition.
        """
        intPtrvalue: c_void_p = value.Ptr

        GetDllLibPdf().Pdf3DNodeCollection_Add.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().Pdf3DNodeCollection_Add.restype = c_int
        ret = CallCFunction(GetDllLibPdf().Pdf3DNodeCollection_Add,self.Ptr, intPtrvalue)
        return ret


    def Contains(self, value: 'Pdf3DNode') -> bool:
        """
        Determines whether the collection contains the specified value.

        Args:
            value: The value to check.

        Returns:
            True if the collection contains the specified value, False otherwise.
        """
        intPtrvalue: c_void_p = value.Ptr

        GetDllLibPdf().Pdf3DNodeCollection_Contains.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().Pdf3DNodeCollection_Contains.restype = c_bool
        ret = CallCFunction(GetDllLibPdf().Pdf3DNodeCollection_Contains,self.Ptr, intPtrvalue)
        return ret


    def IndexOf(self, value: 'Pdf3DNode') -> int:
        """
        Returns the index of the specified value in the collection.

        Args:
            value: The value to find.

        Returns:
            The index of the value.
        """
        intPtrvalue: c_void_p = value.Ptr

        GetDllLibPdf().Pdf3DNodeCollection_IndexOf.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().Pdf3DNodeCollection_IndexOf.restype = c_int
        ret = CallCFunction(GetDllLibPdf().Pdf3DNodeCollection_IndexOf,self.Ptr, intPtrvalue)
        return ret


    def Insert(self, index: int, value: 'Pdf3DNode'):
        """
        Inserts the specified value at the specified index.

        Args:
            index: The index to insert the value at.
            value: The value to insert.
        """
        intPtrvalue: c_void_p = value.Ptr

        GetDllLibPdf().Pdf3DNodeCollection_Insert.argtypes = [c_void_p, c_int, c_void_p]
        CallCFunction(GetDllLibPdf().Pdf3DNodeCollection_Insert,self.Ptr, index, intPtrvalue)


    def Remove(self, value: 'Pdf3DNode'):
        """
        Removes the specified value from the collection.

        Args:
            value: The value to remove.
        """
        intPtrvalue: c_void_p = value.Ptr

        GetDllLibPdf().Pdf3DNodeCollection_Remove.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().Pdf3DNodeCollection_Remove,self.Ptr, intPtrvalue)


    def get_Item(self, index: int) -> 'Pdf3DNode':
        """
        Gets the value at the specified index.

        Args:
            index: The index of the value.

        Returns:
            The value at the specified index.
        """
        GetDllLibPdf().Pdf3DNodeCollection_get_Item.argtypes = [c_void_p, c_int]
        GetDllLibPdf().Pdf3DNodeCollection_get_Item.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().Pdf3DNodeCollection_get_Item,self.Ptr, index)
        ret = None if intPtr == None else Pdf3DNode(intPtr)
        return ret


    def set_Item(self, index: int, value: 'Pdf3DNode'):
        """
        Sets the value at the specified index.

        Args:
            index: The index to set the value at.
            value: The value to set.
        """
        intPtrvalue: c_void_p = value.Ptr

        GetDllLibPdf().Pdf3DNodeCollection_set_Item.argtypes = [c_void_p, c_int, c_void_p]
        CallCFunction(GetDllLibPdf().Pdf3DNodeCollection_set_Item,self.Ptr, index, intPtrvalue)