from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class Pdf3DRendermode(SpireObject):
    """
    Represents the rendering mode of the 3D artwork.
    """

    @dispatch
    def __init__(self):
        """
        Initializes a new instance of the Pdf3DRendermode class.
        """
        GetDllLibPdf().Pdf3DRendermode_CreatePdf3DRendermode.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().Pdf3DRendermode_CreatePdf3DRendermode)
        super(Pdf3DRendermode, self).__init__(intPtr)

    @dispatch
    def __init__(self, style: Pdf3DRenderStyle):
        """
        Initializes a new instance of the Pdf3DRendermode class with the specified style.

        Args:
            style (Pdf3DRenderStyle): The style of the projection.
        """
        enumStyle: c_int = style.value
        GetDllLibPdf().Pdf3DRendermode_CreatePdf3DRendermodeS.argtypes = [c_int]
        GetDllLibPdf().Pdf3DRendermode_CreatePdf3DRendermodeS.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().Pdf3DRendermode_CreatePdf3DRendermodeS,enumStyle)
        super(Pdf3DRendermode, self).__init__(intPtr)

    @property
    def Style(self) -> 'Pdf3DRenderStyle':
        """
        Gets or sets the type of the projection.

        Returns:
            Pdf3DRenderStyle: The type of the projection.
        """
        GetDllLibPdf().Pdf3DRendermode_get_Style.argtypes = [c_void_p]
        GetDllLibPdf().Pdf3DRendermode_get_Style.restype = c_int
        ret = CallCFunction(GetDllLibPdf().Pdf3DRendermode_get_Style,self.Ptr)
        objwrapped = Pdf3DRenderStyle(ret)
        return objwrapped

    @Style.setter
    def Style(self, value: 'Pdf3DRenderStyle'):
        """
        Sets the type of the projection.

        Args:
            value (Pdf3DRenderStyle): The type of the projection.
        """
        GetDllLibPdf().Pdf3DRendermode_set_Style.argtypes = [c_void_p, c_int]
        CallCFunction(GetDllLibPdf().Pdf3DRendermode_set_Style,self.Ptr, value.value)

    @property
    def AuxilaryColor(self) -> 'PdfRGBColor':
        """
        Gets or sets the Auxiliary color.

        Returns:
            PdfRGBColor: The Auxiliary color.
        """
        GetDllLibPdf().Pdf3DRendermode_get_AuxilaryColor.argtypes = [c_void_p]
        GetDllLibPdf().Pdf3DRendermode_get_AuxilaryColor.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().Pdf3DRendermode_get_AuxilaryColor,self.Ptr)
        ret = None if intPtr == None else PdfRGBColor(intPtr)
        return ret

    @AuxilaryColor.setter
    def AuxilaryColor(self, value: 'PdfRGBColor'):
        """
        Sets the Auxiliary color.

        Args:
            value (PdfRGBColor): The Auxiliary color.
        """
        GetDllLibPdf().Pdf3DRendermode_set_AuxilaryColor.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().Pdf3DRendermode_set_AuxilaryColor,self.Ptr, value.Ptr)

    @property
    def FaceColor(self) -> 'PdfRGBColor':
        """
        Gets or sets the Face color.

        Returns:
            PdfRGBColor: The Face color.
        """
        GetDllLibPdf().Pdf3DRendermode_get_FaceColor.argtypes = [c_void_p]
        GetDllLibPdf().Pdf3DRendermode_get_FaceColor.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().Pdf3DRendermode_get_FaceColor,self.Ptr)
        ret = None if intPtr == None else PdfRGBColor(intPtr)
        return ret

    @FaceColor.setter
    def FaceColor(self, value: 'PdfRGBColor'):
        """
        Sets the Face color.

        Args:
            value (PdfRGBColor): The Face color.
        """
        GetDllLibPdf().Pdf3DRendermode_set_FaceColor.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().Pdf3DRendermode_set_FaceColor,self.Ptr, value.Ptr)

    @property
    def CreaseValue(self) -> float:
        """
        Gets or sets the crease value.

        Returns:
            float: The crease value.
        """
        GetDllLibPdf().Pdf3DRendermode_get_CreaseValue.argtypes = [c_void_p]
        GetDllLibPdf().Pdf3DRendermode_get_CreaseValue.restype = c_float
        ret = CallCFunction(GetDllLibPdf().Pdf3DRendermode_get_CreaseValue,self.Ptr)
        return ret

    @CreaseValue.setter
    def CreaseValue(self, value: float):
        """
        Sets the crease value.

        Args:
            value (float): The crease value.
        """
        GetDllLibPdf().Pdf3DRendermode_set_CreaseValue.argtypes = [c_void_p, c_float]
        CallCFunction(GetDllLibPdf().Pdf3DRendermode_set_CreaseValue,self.Ptr, value)

    @property
    def Opacity(self) -> float:
        """
        Gets or sets the rendering opacity.

        Returns:
            float: The rendering opacity.
        """
        GetDllLibPdf().Pdf3DRendermode_get_Opacity.argtypes = [c_void_p]
        GetDllLibPdf().Pdf3DRendermode_get_Opacity.restype = c_float
        ret = CallCFunction(GetDllLibPdf().Pdf3DRendermode_get_Opacity,self.Ptr)
        return ret

    @Opacity.setter
    def Opacity(self, value: float):
        """
        Sets the rendering opacity.

        Args:
            value (float): The rendering opacity.
        """
        GetDllLibPdf().Pdf3DRendermode_set_Opacity.argtypes = [c_void_p, c_float]
        CallCFunction(GetDllLibPdf().Pdf3DRendermode_set_Opacity,self.Ptr, value)