from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfAnnotationBorder(SpireObject):
    """
    Represents the appearance of an annotation's border.
    """

    @dispatch
    def __init__(self, borderWidth: float):
        """
        Initializes a new instance of the PdfAnnotationBorder class with the specified border width.
        """
        GetDllLibPdf().PdfAnnotationBorder_CreatePdfAnnotationBorderB.argtypes = [c_float]
        GetDllLibPdf().PdfAnnotationBorder_CreatePdfAnnotationBorderB.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfAnnotationBorder_CreatePdfAnnotationBorderB,borderWidth)
        super(PdfAnnotationBorder, self).__init__(intPtr)

    @dispatch
    def __init__(self, borderWidth: float, horizontalRadius: float, verticalRadius: float):
        """
        Initializes a new instance of the PdfAnnotationBorder class with the specified border width, horizontal radius, and vertical radius.
        """
        GetDllLibPdf().PdfAnnotationBorder_CreatePdfAnnotationBorderBHV.argtypes = [c_float, c_float, c_float]
        GetDllLibPdf().PdfAnnotationBorder_CreatePdfAnnotationBorderBHV.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfAnnotationBorder_CreatePdfAnnotationBorderBHV,borderWidth, horizontalRadius, verticalRadius)
        super(PdfAnnotationBorder, self).__init__(intPtr)

    @property
    def HorizontalRadius(self) -> float:
        """
        Gets or sets a horizontal corner radius.
        """
        GetDllLibPdf().PdfAnnotationBorder_get_HorizontalRadius.argtypes = [c_void_p]
        GetDllLibPdf().PdfAnnotationBorder_get_HorizontalRadius.restype = c_float
        ret = CallCFunction(GetDllLibPdf().PdfAnnotationBorder_get_HorizontalRadius,self.Ptr)
        return ret

    @HorizontalRadius.setter
    def HorizontalRadius(self, value: float):
        """
        Sets the horizontal corner radius.
        """
        GetDllLibPdf().PdfAnnotationBorder_set_HorizontalRadius.argtypes = [c_void_p, c_float]
        CallCFunction(GetDllLibPdf().PdfAnnotationBorder_set_HorizontalRadius,self.Ptr, value)

    @property
    def VerticalRadius(self) -> float:
        """
        Gets or sets a vertical corner radius.
        """
        GetDllLibPdf().PdfAnnotationBorder_get_VerticalRadius.argtypes = [c_void_p]
        GetDllLibPdf().PdfAnnotationBorder_get_VerticalRadius.restype = c_float
        ret = CallCFunction(GetDllLibPdf().PdfAnnotationBorder_get_VerticalRadius,self.Ptr)
        return ret

    @VerticalRadius.setter
    def VerticalRadius(self, value: float):
        """
        Sets the vertical corner radius.
        """
        GetDllLibPdf().PdfAnnotationBorder_set_VerticalRadius.argtypes = [c_void_p, c_float]
        CallCFunction(GetDllLibPdf().PdfAnnotationBorder_set_VerticalRadius,self.Ptr, value)

    @property
    def Width(self) -> float:
        """
        Gets or sets the width of the annotation's border.
        """
        GetDllLibPdf().PdfAnnotationBorder_get_Width.argtypes = [c_void_p]
        GetDllLibPdf().PdfAnnotationBorder_get_Width.restype = c_float
        ret = CallCFunction(GetDllLibPdf().PdfAnnotationBorder_get_Width,self.Ptr)
        return ret

    @Width.setter
    def Width(self, value: float):
        """
        Sets the width of the annotation's border.
        """
        GetDllLibPdf().PdfAnnotationBorder_set_Width.argtypes = [c_void_p, c_float]
        CallCFunction(GetDllLibPdf().PdfAnnotationBorder_set_Width,self.Ptr, value)