from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfAppearance(SpireObject):
    """
    Represents the appearance of an annotation.
    """

    @dispatch
    def __init__(self, annotation: PdfAnnotation):
        """
        Initializes a new instance of the PdfAppearance class.

        Args:
            annotation (PdfAnnotation): The PdfAnnotation object.

        Returns:
            None.
        """
        ptrAnno: c_void_p = annotation.Ptr
        GetDllLibPdf().PdfAppearance_CreatePdfAppearanceA.argtypes = [c_void_p]
        GetDllLibPdf().PdfAppearance_CreatePdfAppearanceA.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfAppearance_CreatePdfAppearanceA,ptrAnno)
        super(PdfAppearance, self).__init__(intPtr)

    @property
    def Normal(self) -> 'PdfTemplate':
        """
        Gets or sets the object which is applied to the annotation in normal state.

        Returns:
            PdfTemplate: The PdfTemplate object.
        """
        GetDllLibPdf().PdfAppearance_get_Normal.argtypes = [c_void_p]
        GetDllLibPdf().PdfAppearance_get_Normal.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfAppearance_get_Normal,self.Ptr)
        ret = None if intPtr == None else PdfTemplate(intPtr)
        return ret

    @Normal.setter
    def Normal(self, value: 'PdfTemplate'):
        """
        Sets the object which is applied to the annotation in normal state.

        Args:
            value (PdfTemplate): The PdfTemplate object.

        Returns:
            None.
        """
        GetDllLibPdf().PdfAppearance_set_Normal.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfAppearance_set_Normal,self.Ptr, value.Ptr)

    @property
    def MouseHover(self) -> 'PdfTemplate':
        """
        Gets or sets the object which is applied to the annotation on hovering the mouse.

        Returns:
            PdfTemplate: The PdfTemplate object.
        """
        GetDllLibPdf().PdfAppearance_get_MouseHover.argtypes = [c_void_p]
        GetDllLibPdf().PdfAppearance_get_MouseHover.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfAppearance_get_MouseHover,self.Ptr)
        ret = None if intPtr == None else PdfTemplate(intPtr)
        return ret

    @MouseHover.setter
    def MouseHover(self, value: 'PdfTemplate'):
        """
        Sets the object which is applied to the annotation on hovering the mouse.

        Args:
            value (PdfTemplate): The PdfTemplate object.

        Returns:
            None.
        """
        GetDllLibPdf().PdfAppearance_set_MouseHover.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfAppearance_set_MouseHover,self.Ptr, value.Ptr)

    @property
    def Pressed(self) -> 'PdfTemplate':
        """
        Gets or sets the object which is applied to the annotation when the mouse button is pressed.

        Returns:
            PdfTemplate: The PdfTemplate object.
        """
        GetDllLibPdf().PdfAppearance_get_Pressed.argtypes = [c_void_p]
        GetDllLibPdf().PdfAppearance_get_Pressed.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfAppearance_get_Pressed,self.Ptr)
        ret = None if intPtr == None else PdfTemplate(intPtr)
        return ret

    @Pressed.setter
    def Pressed(self, value: 'PdfTemplate'):
        """
        Sets the object which is applied to the annotation when the mouse button is pressed.

        Args:
            value (PdfTemplate): The PdfTemplate object.

        Returns:
            None.
        """
        GetDllLibPdf().PdfAppearance_set_Pressed.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfAppearance_set_Pressed,self.Ptr, value.Ptr)