from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfBookmarkWidget(PdfBookmark):
    """
    Represents loaded bookmark class.
    """

    @property
    def Destination(self) -> 'PdfDestination':
        """
        Gets or sets the outline destination.
        """
        GetDllLibPdf().PdfBookmarkWidget_get_Destination.argtypes = [c_void_p]
        GetDllLibPdf().PdfBookmarkWidget_get_Destination.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfBookmarkWidget_get_Destination,self.Ptr)
        ret = None if intPtr == None else PdfDestination(intPtr)
        return ret

    @Destination.setter
    def Destination(self, value: 'PdfDestination'):
        """
        Sets the outline destination.
        """
        GetDllLibPdf().PdfBookmarkWidget_set_Destination.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfBookmarkWidget_set_Destination,self.Ptr, value.Ptr)

    @property
    def Title(self) -> str:
        """
        Gets or sets the outline title.
        """
        GetDllLibPdf().PdfBookmarkWidget_get_Title.argtypes = [c_void_p]
        GetDllLibPdf().PdfBookmarkWidget_get_Title.restype = c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfBookmarkWidget_get_Title,self.Ptr))
        return ret

    @Title.setter
    def Title(self, value: str):
        """
        Sets the outline title.
        """
        GetDllLibPdf().PdfBookmarkWidget_set_Title.argtypes = [c_void_p, c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfBookmarkWidget_set_Title,self.Ptr, value)

    @property
    def Color(self) -> 'PdfRGBColor':
        """
        Gets or sets the color.
        """
        GetDllLibPdf().PdfBookmarkWidget_get_Color.argtypes = [c_void_p]
        GetDllLibPdf().PdfBookmarkWidget_get_Color.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfBookmarkWidget_get_Color,self.Ptr)
        ret = None if intPtr == None else PdfRGBColor(intPtr)
        return ret

    @Color.setter
    def Color(self, value: 'PdfRGBColor'):
        """
        Sets the color.
        """
        GetDllLibPdf().PdfBookmarkWidget_set_Color.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfBookmarkWidget_set_Color,self.Ptr, value.Ptr)

    @property
    def DisplayStyle(self) -> 'PdfTextStyle':
        """
        Gets or sets the text style.
        """
        GetDllLibPdf().PdfBookmarkWidget_get_DisplayStyle.argtypes = [c_void_p]
        GetDllLibPdf().PdfBookmarkWidget_get_DisplayStyle.restype = c_int
        ret = CallCFunction(GetDllLibPdf().PdfBookmarkWidget_get_DisplayStyle,self.Ptr)
        objwrapped = PdfTextStyle(ret)
        return objwrapped

    @DisplayStyle.setter
    def DisplayStyle(self, value: 'PdfTextStyle'):
        """
        Sets the text style.
        """
        GetDllLibPdf().PdfBookmarkWidget_set_DisplayStyle.argtypes = [c_void_p, c_int]
        CallCFunction(GetDllLibPdf().PdfBookmarkWidget_set_DisplayStyle,self.Ptr, value.value)