from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfButtonWidgetFieldWidget(PdfStyledFieldWidget):
    """
    Represents a button field of an existing PDF document's form.
    """

    @property
    def Text(self) -> str:
        """
        Gets or sets the caption text.

        Returns:
            A string value specifying the caption of the button.
        """
        GetDllLibPdf().PdfButtonWidgetFieldWidget_get_Text.argtypes = [c_void_p]
        GetDllLibPdf().PdfButtonWidgetFieldWidget_get_Text.restype = c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfButtonWidgetFieldWidget_get_Text,self.Ptr))
        return ret

    @Text.setter
    def Text(self, value: str):
        """
        Sets the caption text.

        Args:
            value: A string value specifying the caption of the button.
        """
        GetDllLibPdf().PdfButtonWidgetFieldWidget_set_Text.argtypes = [c_void_p, c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfButtonWidgetFieldWidget_set_Text,self.Ptr, value)

    @property
    def WidgetItems(self) -> 'PdfButtonWidgetItemCollection':
        """
        Gets the collection of button items.
        """
        GetDllLibPdf().PdfButtonWidgetFieldWidget_get_WidgetItems.argtypes = [c_void_p]
        GetDllLibPdf().PdfButtonWidgetFieldWidget_get_WidgetItems.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfButtonWidgetFieldWidget_get_WidgetItems,self.Ptr)
        ret = None if intPtr == None else PdfButtonWidgetItemCollection(intPtr)
        return ret

    @property
    def IconLayout(self) -> 'PdfButtonIconLayout':
        """
        Defining the icon layout.
        """
        GetDllLibPdf().PdfButtonWidgetFieldWidget_get_IconLayout.argtypes = [c_void_p]
        GetDllLibPdf().PdfButtonWidgetFieldWidget_get_IconLayout.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfButtonWidgetFieldWidget_get_IconLayout,self.Ptr)
        ret = None if intPtr == None else PdfButtonIconLayout(intPtr)
        return ret

    def SetButtonImage(self, image: 'PdfImage'):
        """
        Sets the button image.

        Args:
            image: The image to be set.
        """
        intPtrimage: c_void_p = image.Ptr

        GetDllLibPdf().PdfButtonWidgetFieldWidget_SetButtonImage.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfButtonWidgetFieldWidget_SetButtonImage,self.Ptr, intPtrimage)

    def AddPrintAction(self):
        """
        Adds Print action to current button field.

        Remarks:
            Clicking on the specified button will trigger the Print Dialog Box.
        """
        GetDllLibPdf().PdfButtonWidgetFieldWidget_AddPrintAction.argtypes = [c_void_p]
        CallCFunction(GetDllLibPdf().PdfButtonWidgetFieldWidget_AddPrintAction,self.Ptr)

    def ObjectID(self) -> int:
        """
        Gets the form field identifier.

        Returns:
            The form field identifier.
        """
        GetDllLibPdf().PdfButtonWidgetFieldWidget_ObjectID.argtypes = [c_void_p]
        GetDllLibPdf().PdfButtonWidgetFieldWidget_ObjectID.restype = c_int
        ret = CallCFunction(GetDllLibPdf().PdfButtonWidgetFieldWidget_ObjectID,self.Ptr)
        return ret