from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfColorBlend(PdfBlendBase):
    """
    Represents the arrays of colors and positions used for
    interpolating color blending in a multicolor gradient.
    """

    @property
    def Colors(self) -> List['PdfRGBColor']:
        """
        Gets or sets the colours array.
        """
        GetDllLibPdf().PdfColorBlend_get_Colors.argtypes = [c_void_p]
        GetDllLibPdf().PdfColorBlend_get_Colors.restype = IntPtrArray
        intPtrArray = CallCFunction(GetDllLibPdf().PdfColorBlend_get_Colors,self.Ptr)
        ret = GetVectorFromArray(intPtrArray, PdfRGBColor)
        return ret

    @Colors.setter
    def Colors(self, value: List['PdfRGBColor']):
        """
        Sets the colours array.
        """
        vCount = len(value)
        ArrayType = c_void_p * vCount
        vArray = ArrayType()
        for i in range(0, vCount):
            vArray[i] = value[i].Ptr
        GetDllLibPdf().PdfColorBlend_set_Colors.argtypes = [c_void_p, ArrayType, c_int]
        CallCFunction(GetDllLibPdf().PdfColorBlend_set_Colors,self.Ptr, vArray, vCount)