from enum import Enum
from plum import dispatch
from typing import TypeVar,Union,Generic,List,Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfDocumentBase (SpireObject) :
    """
        Represent common PdfDocumentBase classes.
    """
    @dispatch

    def SaveToPostScript(self ,filename:str):
        """

        """
        
        GetDllLibPdf().PdfDocumentBase_SaveToPostScript.argtypes=[c_void_p ,c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfDocumentBase_SaveToPostScript,self.Ptr, filename)

    @dispatch

    def SaveToDoc(self ,stream:Stream,IsDocx:bool):
        """
        Save the document to doc as stream[].

        Args:
            stream (Stream): The doc stream.
			IsDocx (bool): Is docs or doc.
        """ 		
        intPtrstream:c_void_p = stream.Ptr

        GetDllLibPdf().PdfDocumentBase_SaveToDoc.argtypes=[c_void_p ,c_void_p,c_bool]
        CallCFunction(GetDllLibPdf().PdfDocumentBase_SaveToDoc,self.Ptr, intPtrstream,IsDocx)

    @dispatch

    def SaveToDoc(self ,filename:str):
        """

        """
        
        GetDllLibPdf().PdfDocumentBase_SaveToDocF.argtypes=[c_void_p ,c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfDocumentBase_SaveToDocF,self.Ptr, filename)

    @dispatch
    def Close(self):
        """
        Closes the document. Releases all common resources.
        """
        GetDllLibPdf().PdfDocumentBase_Close.argtypes=[c_void_p]
        CallCFunction(GetDllLibPdf().PdfDocumentBase_Close,self.Ptr)

    @dispatch

    def Close(self ,completely:bool):
        """
        Closes the document.

        Args:
            completely (bool): if set to <c>true</c> the document should close its stream as well.
        """         
        GetDllLibPdf().PdfDocumentBase_CloseC.argtypes=[c_void_p ,c_bool]
        CallCFunction(GetDllLibPdf().PdfDocumentBase_CloseC,self.Ptr, completely)

    @dispatch

    def Save(self ,stream:Stream):
        """
        Saves the document to the specified stream.

        Args:
            stream (Stream): The stream object where PDF document will be saved.
        """ 		
        intPtrstream:c_void_p = stream.Ptr

        GetDllLibPdf().PdfDocumentBase_Save.argtypes=[c_void_p ,c_void_p]
        CallCFunction(GetDllLibPdf().PdfDocumentBase_Save,self.Ptr, intPtrstream)

    @dispatch

    def ImportPage(self ,ldDoc:'PdfDocumentBase',page:'PdfPageBase')->'PdfPageBase':
        """
        Imports a page.

        Args:
            ldDoc (PdfDocumentBase): The loaded document.
			page (PdfPageBase): The page.

        Returns:
            PdfPageBase: The page in the result document.
        """		
        intPtrldDoc:c_void_p = ldDoc.Ptr
        intPtrpage:c_void_p = page.Ptr

        GetDllLibPdf().PdfDocumentBase_ImportPage.argtypes=[c_void_p ,c_void_p,c_void_p]
        GetDllLibPdf().PdfDocumentBase_ImportPage.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfDocumentBase_ImportPage,self.Ptr, intPtrldDoc,intPtrpage)
        ret = None if intPtr==None else PdfPageBase(intPtr)
        return ret


    @dispatch

    def ImportPage(self ,ldDoc:'PdfDocumentBase',pageIndex:int)->'PdfPageBase':
        """
        Imports a page.

        Args:
            ldDoc (PdfDocumentBase): The loaded document.
			pageIndex (int): Index of the page.

        Returns:
            PdfPageBase: The page in the result document.
        """			
        intPtrldDoc:c_void_p = ldDoc.Ptr

        GetDllLibPdf().PdfDocumentBase_ImportPageLP.argtypes=[c_void_p ,c_void_p,c_int]
        GetDllLibPdf().PdfDocumentBase_ImportPageLP.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfDocumentBase_ImportPageLP,self.Ptr, intPtrldDoc,pageIndex)
        ret = None if intPtr==None else PdfPageBase(intPtr)
        return ret


    @dispatch

    def ImportPage(self ,ldDoc:'PdfDocumentBase',pageIndex:int,resultPageIndex:int)->'PdfPageBase':
        """
        Imports a page.

        Args:
            ldDoc (PdfDocumentBase): The loaded document.
			pageIndex (int): Index of the page.
			resultPageIndex (int): The page index in the result document.

        Returns:
            PdfPageBase: The page in the result document.
        """			
        intPtrldDoc:c_void_p = ldDoc.Ptr

        GetDllLibPdf().PdfDocumentBase_ImportPageLPR.argtypes=[c_void_p ,c_void_p,c_int,c_int]
        GetDllLibPdf().PdfDocumentBase_ImportPageLPR.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfDocumentBase_ImportPageLPR,self.Ptr, intPtrldDoc,pageIndex,resultPageIndex)
        ret = None if intPtr==None else PdfPageBase(intPtr)
        return ret


    @dispatch

    def ImportPageRange(self ,ldDoc:'PdfDocumentBase',startIndex:int,endIndex:int)->'PdfPageBase':
        """
        Imports a page range from a loaded document.

        Args:
            ldDoc (PdfDocumentBase): The loaded document.
			startIndex (int): The start page index.
			endIndex (int): The end page index.

        Returns:
            PdfPageBase: The last created page in the result document.
        """			
        intPtrldDoc:c_void_p = ldDoc.Ptr

        GetDllLibPdf().PdfDocumentBase_ImportPageRange.argtypes=[c_void_p ,c_void_p,c_int,c_int]
        GetDllLibPdf().PdfDocumentBase_ImportPageRange.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfDocumentBase_ImportPageRange,self.Ptr, intPtrldDoc,startIndex,endIndex)
        ret = None if intPtr==None else PdfPageBase(intPtr)
        return ret


    @dispatch

    def ImportPageRange(self ,ldDoc:'PdfDocumentBase',startIndex:int,endIndex:int,resultPageIndex:int)->'PdfPageBase':
        """
        Imports a page range from a loaded document.

        Args:
            ldDoc (PdfDocumentBase): The loaded document.
			startIndex (int): The start page index.
			endIndex (int): The end page index.
			resultPageIndex (int): The page index in the result document when startIndex == endIndex.

        Returns:
            PdfPageBase: The last created page in the result document.
        """				
        intPtrldDoc:c_void_p = ldDoc.Ptr

        GetDllLibPdf().PdfDocumentBase_ImportPageRangeLSER.argtypes=[c_void_p ,c_void_p,c_int,c_int,c_int]
        GetDllLibPdf().PdfDocumentBase_ImportPageRangeLSER.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfDocumentBase_ImportPageRangeLSER,self.Ptr, intPtrldDoc,startIndex,endIndex,resultPageIndex)
        ret = None if intPtr==None else PdfPageBase(intPtr)
        return ret


    def Dispose(self):
        """

        """
        GetDllLibPdf().PdfDocumentBase_Dispose.argtypes=[c_void_p]
        CallCFunction(GetDllLibPdf().PdfDocumentBase_Dispose,self.Ptr)

    @property

    def Conformance(self)->'PdfConformanceLevel':
        """
        The conformance level.
        """
        GetDllLibPdf().PdfDocumentBase_get_Conformance.argtypes=[c_void_p]
        GetDllLibPdf().PdfDocumentBase_get_Conformance.restype=c_int
        ret = CallCFunction(GetDllLibPdf().PdfDocumentBase_get_Conformance,self.Ptr)
        objwraped = PdfConformanceLevel(ret)
        return objwraped

    #@Conformance.setter
    #def Conformance(self, value:'PdfConformanceLevel'):
    #    GetDllLibPdf().PdfDocumentBase_set_Conformance.argtypes=[c_void_p, c_int]
    #    CallCFunction(GetDllLibPdf().PdfDocumentBase_set_Conformance,self.Ptr, value.value)

    @property

    def Attachments(self)->'PdfAttachmentCollection':
        """

        """
        GetDllLibPdf().PdfDocumentBase_get_Attachments.argtypes=[c_void_p]
        GetDllLibPdf().PdfDocumentBase_get_Attachments.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfDocumentBase_get_Attachments,self.Ptr)
        ret = None if intPtr==None else PdfAttachmentCollection(intPtr)
        return ret


    @property

    def ColorSpace(self)->'PdfColorSpace':
        """

        """
        GetDllLibPdf().PdfDocumentBase_get_ColorSpace.argtypes=[c_void_p]
        GetDllLibPdf().PdfDocumentBase_get_ColorSpace.restype=c_int
        ret = CallCFunction(GetDllLibPdf().PdfDocumentBase_get_ColorSpace,self.Ptr)
        objwraped = PdfColorSpace(ret)
        return objwraped

    @ColorSpace.setter
    def ColorSpace(self, value:'PdfColorSpace'):
        GetDllLibPdf().PdfDocumentBase_set_ColorSpace.argtypes=[c_void_p, c_int]
        CallCFunction(GetDllLibPdf().PdfDocumentBase_set_ColorSpace,self.Ptr, value.value)

    @property

    def Form(self)->'PdfForm':
        """

        """
        GetDllLibPdf().PdfDocumentBase_get_Form.argtypes=[c_void_p]
        GetDllLibPdf().PdfDocumentBase_get_Form.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfDocumentBase_get_Form,self.Ptr)
        ret = None if intPtr==None else PdfForm(intPtr)
        return ret


    @property

    def PageLabels(self)->'PdfPageLabels':
        """
        Page labels.
        """
        GetDllLibPdf().PdfDocumentBase_get_PageLabels.argtypes=[c_void_p]
        GetDllLibPdf().PdfDocumentBase_get_PageLabels.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfDocumentBase_get_PageLabels,self.Ptr)
        ret = None if intPtr==None else PdfPageLabels(intPtr)
        return ret


    @PageLabels.setter
    def PageLabels(self, value:'PdfPageLabels'):
        GetDllLibPdf().PdfDocumentBase_set_PageLabels.argtypes=[c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfDocumentBase_set_PageLabels,self.Ptr, value.Ptr)

#    @property
#
#    def UsedFonts(self)->List['PdfUsedFont']:
#        """
#    <summary>
#        Gets the fonts which are available in the PDF document.
#    </summary>
#<value>Retruns the fonts which are used in the PDF document.</value>
#        """
#        GetDllLibPdf().PdfDocumentBase_get_UsedFonts.argtypes=[c_void_p]
#        GetDllLibPdf().PdfDocumentBase_get_UsedFonts.restype=IntPtrArray
#        intPtrArray = CallCFunction(GetDllLibPdf().PdfDocumentBase_get_UsedFonts,self.Ptr)
#        ret = GetVectorFromArray(intPtrArray, PdfUsedFont)
#        return ret


    @property

    def Sections(self)->'PdfSectionCollection':
        """

        """
        GetDllLibPdf().PdfDocumentBase_get_Sections.argtypes=[c_void_p]
        GetDllLibPdf().PdfDocumentBase_get_Sections.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfDocumentBase_get_Sections,self.Ptr)
        ret = None if intPtr==None else PdfSectionCollection(intPtr)
        return ret


    @property

    def PageSettings(self)->'PdfPageSettings':
        """

        """
        GetDllLibPdf().PdfDocumentBase_get_PageSettings.argtypes=[c_void_p]
        GetDllLibPdf().PdfDocumentBase_get_PageSettings.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfDocumentBase_get_PageSettings,self.Ptr)
        ret = None if intPtr==None else PdfPageSettings(intPtr)
        return ret


    @PageSettings.setter
    def PageSettings(self, value:'PdfPageSettings'):
        GetDllLibPdf().PdfDocumentBase_set_PageSettings.argtypes=[c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfDocumentBase_set_PageSettings,self.Ptr, value.Ptr)

    @property

    def Template(self)->'PdfDocumentTemplate':
        """
        Gets or sets a template that is applied to all pages in the document.
		    The  specifying the default template for the document.
        """
        GetDllLibPdf().PdfDocumentBase_get_Template.argtypes=[c_void_p]
        GetDllLibPdf().PdfDocumentBase_get_Template.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfDocumentBase_get_Template,self.Ptr)
        ret = None if intPtr==None else PdfDocumentTemplate(intPtr)
        return ret


    @Template.setter
    def Template(self, value:'PdfDocumentTemplate'):
        GetDllLibPdf().PdfDocumentBase_set_Template.argtypes=[c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfDocumentBase_set_Template,self.Ptr, value.Ptr)

    @property

    def Pages(self)->'PdfPageCollection':
        """
        Gets the pages.
        """
        GetDllLibPdf().PdfDocumentBase_get_Pages.argtypes=[c_void_p]
        GetDllLibPdf().PdfDocumentBase_get_Pages.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfDocumentBase_get_Pages,self.Ptr)
        ret = None if intPtr==None else PdfPageCollection(intPtr)
        return ret


    @property

    def Security(self)->'PdfSecurity':
        """
        Gets the security parameters of the document.
        """
        GetDllLibPdf().PdfDocumentBase_get_Security.argtypes=[c_void_p]
        GetDllLibPdf().PdfDocumentBase_get_Security.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfDocumentBase_get_Security,self.Ptr)
        ret = None if intPtr==None else PdfSecurity(intPtr)
        return ret


    @property

    def DocumentInformation(self)->'PdfDocumentInformation':
        """
        Gets or sets document's information and properties.
        """
        GetDllLibPdf().PdfDocumentBase_get_DocumentInformation.argtypes=[c_void_p]
        GetDllLibPdf().PdfDocumentBase_get_DocumentInformation.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfDocumentBase_get_DocumentInformation,self.Ptr)
        ret = None if intPtr==None else PdfDocumentInformation(intPtr)
        return ret


    @property

    def ViewerPreferences(self)->'PdfViewerPreferences':
        """
        Gets or sets a viewer preferences object controlling the way the document is to be 
            presented on the screen or in print.
        """
        GetDllLibPdf().PdfDocumentBase_get_ViewerPreferences.argtypes=[c_void_p]
        GetDllLibPdf().PdfDocumentBase_get_ViewerPreferences.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfDocumentBase_get_ViewerPreferences,self.Ptr)
        ret = None if intPtr==None else PdfViewerPreferences(intPtr)
        return ret


    @ViewerPreferences.setter
    def ViewerPreferences(self, value:'PdfViewerPreferences'):
        GetDllLibPdf().PdfDocumentBase_set_ViewerPreferences.argtypes=[c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfDocumentBase_set_ViewerPreferences,self.Ptr, value.Ptr)

    @property

    def CompressionLevel(self)->'PdfCompressionLevel':
        """
        Gets or sets the desired level of stream compression.
		    All new objects should be compressed with this level of the compression.
        """
        GetDllLibPdf().PdfDocumentBase_get_CompressionLevel.argtypes=[c_void_p]
        GetDllLibPdf().PdfDocumentBase_get_CompressionLevel.restype=c_int
        ret = CallCFunction(GetDllLibPdf().PdfDocumentBase_get_CompressionLevel,self.Ptr)
        objwraped = PdfCompressionLevel(ret)
        return objwraped

    @CompressionLevel.setter
    def CompressionLevel(self, value:'PdfCompressionLevel'):
        GetDllLibPdf().PdfDocumentBase_set_CompressionLevel.argtypes=[c_void_p, c_int]
        CallCFunction(GetDllLibPdf().PdfDocumentBase_set_CompressionLevel,self.Ptr, value.value)

    @property

    def FileStructure(self)->'PdfFileInfo':
        """
        Gets or sets the internal structure of the PDF file.
        """
        GetDllLibPdf().PdfDocumentBase_get_FileStructure.argtypes=[c_void_p]
        GetDllLibPdf().PdfDocumentBase_get_FileStructure.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfDocumentBase_get_FileStructure,self.Ptr)
        ret = None if intPtr==None else PdfFileInfo(intPtr)
        return ret


    @FileStructure.setter
    def FileStructure(self, value:'PdfFileInfo'):
        GetDllLibPdf().PdfDocumentBase_set_FileStructure.argtypes=[c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfDocumentBase_set_FileStructure,self.Ptr, value.Ptr)

    @property

    def JavaScripts(self)->'PdfDocumentActions':
        """
        Gets the additional document's actions.
		    The  specifying the document action.
        """
        GetDllLibPdf().PdfDocumentBase_get_JavaScripts.argtypes=[c_void_p]
        GetDllLibPdf().PdfDocumentBase_get_JavaScripts.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfDocumentBase_get_JavaScripts,self.Ptr)
        ret = None if intPtr==None else PdfDocumentActions(intPtr)
        return ret


    @property

    def Bookmarks(self)->'PdfBookmarkCollection':
        """
        Gets the bookmarks.
        """
        GetDllLibPdf().PdfDocumentBase_get_Bookmarks.argtypes=[c_void_p]
        GetDllLibPdf().PdfDocumentBase_get_Bookmarks.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfDocumentBase_get_Bookmarks,self.Ptr)
        ret = None if intPtr==None else PdfBookmarkCollection(intPtr)
        return ret



    def Clone(self)->'SpireObject':
        """

        """
        GetDllLibPdf().PdfDocumentBase_Clone.argtypes=[c_void_p]
        GetDllLibPdf().PdfDocumentBase_Clone.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfDocumentBase_Clone,self.Ptr)
        ret = None if intPtr==None else SpireObject(intPtr)
        return ret


    @dispatch

    def Split(self ,destFilePattern:str):
        """
        Splits a PDF file to many PDF files, each of them consists of one page from the source file.

        Args:
            destFilePattern (str): Template for destination file names.
        """        
        GetDllLibPdf().PdfDocumentBase_Split.argtypes=[c_void_p ,c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfDocumentBase_Split,self.Ptr, destFilePattern)

    @dispatch

    def Split(self ,destFilePattern:str,startNumber:int):
        """
        Splits a PDF file to many PDF files, each of them consists of
            one page from the source file.

        Args:
            destFilePattern (str): Template for destination file names.
			startNumber (int): The number that is use as a start point for the page numbering.
        """           
        GetDllLibPdf().PdfDocumentBase_SplitDS.argtypes=[c_void_p ,c_wchar_p,c_int]
        CallCFunction(GetDllLibPdf().PdfDocumentBase_SplitDS,self.Ptr, destFilePattern,startNumber)

    @staticmethod

    def Merge(dest:'PdfDocumentBase',sourceDocuments:List['SpireObject'])->'PdfDocumentBase':
        """
        Merges the specified source documents and return destination document.

        Args:
            dest (PdfDocumentBase): The destination document, where the other documents are merged into.If it's null a new document object will be created.
			sourceDocuments (List['SpireObject']): The source documents.
        Returns:
            PdfDocumentBase: The document containing merged documents.
        """  		
        intPtrdest:c_void_p = dest.Ptr
        #arraysourceDocuments:ArrayTypesourceDocuments = ""
        countsourceDocuments = len(sourceDocuments)
        ArrayTypesourceDocuments = c_void_p * countsourceDocuments
        arraysourceDocuments = ArrayTypesourceDocuments()
        for i in range(0, countsourceDocuments):
            arraysourceDocuments[i] = sourceDocuments[i].Ptr


        GetDllLibPdf().PdfDocumentBase_Merge.argtypes=[ c_void_p,ArrayTypesourceDocuments]
        GetDllLibPdf().PdfDocumentBase_Merge.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfDocumentBase_Merge, intPtrdest,arraysourceDocuments)
        ret = None if intPtr==None else PdfDocumentBase(intPtr)
        return ret


#
#    def DisposeOnClose(self ,obj:'IDisposable'):
#        """
#    <summary>
#        Adds an object to a collection of the objects that will be disposed during document closing.
#    </summary>
#    <param name="obj">The object that will be disposed during document closing.</param>
#        """
#        intPtrobj:c_void_p = obj.Ptr
#
#        GetDllLibPdf().PdfDocumentBase_DisposeOnClose.argtypes=[c_void_p ,c_void_p]
#        CallCFunction(GetDllLibPdf().PdfDocumentBase_DisposeOnClose,self.Ptr, intPtrobj)


    @dispatch

    def Save(self ,fileName:str,fileformat:FileFormat):
        """

        """
        enumfileformat:c_int = fileformat.value

        GetDllLibPdf().PdfDocumentBase_SaveFF.argtypes=[c_void_p ,c_wchar_p,c_int]
        CallCFunction(GetDllLibPdf().PdfDocumentBase_SaveFF,self.Ptr, fileName,enumfileformat)

    @dispatch

    def Save(self ,stream:Stream,fileformat:FileFormat):
        """
        Convert the document to an stream with the file format.

        Args:
            stream (Stream): The stream with the file format.
			fileformat (FileFormat): The file format.FileFormat.SVG is not supported, because SVG file has no paging,so can't be saved to an stream.
        """		
        intPtrstream:c_void_p = stream.Ptr
        enumfileformat:c_int = fileformat.value

        GetDllLibPdf().PdfDocumentBase_SaveSF.argtypes=[c_void_p ,c_void_p,c_int]
        CallCFunction(GetDllLibPdf().PdfDocumentBase_SaveSF,self.Ptr, intPtrstream,enumfileformat)

#    @dispatch
#
#    def Save(self ,fileformat:FileFormat)->List[Stream]:
#        """
#    <summary>
#        Convert the document to streams with the file format.
#    </summary>
#    <param name="fileformat">The file format.</param>
#    <returns>
#            The format file streams.
#            FileFormat.PDF:return only one stream(PDF support paging).
#            FileFormat.XPS:return only one stream(XPS support paging).
#            FileFormat.DOC:return only one stream(DOC support paging).
#            FileFormat.DOCX:return only one stream(DOCX support paging).
#            FileFormat.XLSX:return only one stream(XLSX support paging).
#            FileFormat.PCL:return only one stream(PCL support paging).
#            FileFormat.POSTSCRIPT:return only one stream(POSTSCRIPT support paging).
#            FileFormat.HTML:return only one stream(HTML support paging).
#            FileFormat.SVG:return multiple streams(SVG not support paging,one stream to one page).
#            </returns>
#        """
#        enumfileformat:c_int = fileformat.value
#
#        GetDllLibPdf().PdfDocumentBase_SaveF.argtypes=[c_void_p ,c_int]
#        GetDllLibPdf().PdfDocumentBase_SaveF.restype=IntPtrArray
#        intPtrArray = CallCFunction(GetDllLibPdf().PdfDocumentBase_SaveF,self.Ptr, enumfileformat)
#        ret = GetObjVectorFromArray(intPtrArray, Stream)
#        return ret


#    @dispatch
#
#    def Save(self ,startIndex:int,endIndex:int,fileformat:FileFormat)->List[Stream]:
#        """
#    <summary>
#        Convert the document to streams with the file format.
#    </summary>
#    <param name="startIndex">The start index.</param>
#    <param name="endIndex">The end index.</param>
#    <param name="fileformat">The file format.</param>
#    <returns>
#            The format file streams.
#            FileFormat.PDF:return only one stream(PDF support paging).
#            FileFormat.XPS:return only one stream(XPS support paging).
#            FileFormat.DOC:return only one stream(DOC support paging).
#            FileFormat.DOCX:return only one stream(DOCX support paging).
#            FileFormat.XLSX:return only one stream(XLSX support paging).
#            FileFormat.PCL:return only one stream(PCL support paging).
#            FileFormat.POSTSCRIPT:return only one stream(POSTSCRIPT support paging).
#            FileFormat.HTML:return only one stream(HTML support paging).
#            FileFormat.SVG:return multiple streams(SVG not support paging,one stream to one page).
#            </returns>
#        """
#        enumfileformat:c_int = fileformat.value
#
#        GetDllLibPdf().PdfDocumentBase_SaveSEF.argtypes=[c_void_p ,c_int,c_int,c_int]
#        GetDllLibPdf().PdfDocumentBase_SaveSEF.restype=IntPtrArray
#        intPtrArray = CallCFunction(GetDllLibPdf().PdfDocumentBase_SaveSEF,self.Ptr, startIndex,endIndex,enumfileformat)
#        ret = GetObjVectorFromArray(intPtrArray, Stream)
#        return ret


    @dispatch

    def Save(self ,filename:str):
        """
        Saves the document to the specified filename.

        Args:
            filename (str): The filename.
        """
        GetDllLibPdf().PdfDocumentBase_SaveF1.argtypes=[c_void_p ,c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfDocumentBase_SaveF1,self.Ptr, filename)

    @dispatch

    def SaveToXPS(self ,stream:Stream):
        """
        Save the document to xps as stream.

        Args:
            stream (Stream): The xps stream.
        """		
        intPtrstream:c_void_p = stream.Ptr

        GetDllLibPdf().PdfDocumentBase_SaveToXPS.argtypes=[c_void_p ,c_void_p]
        CallCFunction(GetDllLibPdf().PdfDocumentBase_SaveToXPS,self.Ptr, intPtrstream)

    @dispatch

    def SaveToXPS(self ,savefilename:str):
        """

        """
        
        GetDllLibPdf().PdfDocumentBase_SaveToXPSS.argtypes=[c_void_p ,c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfDocumentBase_SaveToXPSS,self.Ptr, savefilename)

#
#    def SaveToSVG(self)->List['Stream']:
#        """
#    <summary>
#        Save the document to svg as stream[].
#    </summary>
#    <returns>Stream collection</returns>
#        """
#        GetDllLibPdf().PdfDocumentBase_SaveToSVG.argtypes=[c_void_p]
#        GetDllLibPdf().PdfDocumentBase_SaveToSVG.restype=IntPtrArray
#        intPtrArray = CallCFunction(GetDllLibPdf().PdfDocumentBase_SaveToSVG,self.Ptr)
#        ret = GetVectorFromArray(intPtrArray, Stream)
#        return ret


    @dispatch

    def SaveToHtml(self ,filename:str):
        """

        """
        
        GetDllLibPdf().PdfDocumentBase_SaveToHtml.argtypes=[c_void_p ,c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfDocumentBase_SaveToHtml,self.Ptr, filename)

    @dispatch

    def SaveToHtml(self ,stream:Stream):
        """
        Save the document to html stream.

        Args:
            stream (Stream): The html stream.
        """			
        intPtrstream:c_void_p = stream.Ptr

        GetDllLibPdf().PdfDocumentBase_SaveToHtmlS.argtypes=[c_void_p ,c_void_p]
        CallCFunction(GetDllLibPdf().PdfDocumentBase_SaveToHtmlS,self.Ptr, intPtrstream)

    @dispatch

    def SaveToPcl(self ,stream:Stream):
        """

        """
        intPtrstream:c_void_p = stream.Ptr

        GetDllLibPdf().PdfDocumentBase_SaveToPcl.argtypes=[c_void_p ,c_void_p]
        CallCFunction(GetDllLibPdf().PdfDocumentBase_SaveToPcl,self.Ptr, intPtrstream)

    @dispatch

    def SaveToPcl(self ,filename:str):
        """

        """
        
        GetDllLibPdf().PdfDocumentBase_SaveToPclF.argtypes=[c_void_p ,c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfDocumentBase_SaveToPclF,self.Ptr, filename)

    @dispatch

    def SaveToPostScript(self ,stream:Stream):
        """

        """
        intPtrstream:c_void_p = stream.Ptr

        GetDllLibPdf().PdfDocumentBase_SaveToPostScriptS.argtypes=[c_void_p ,c_void_p]
        CallCFunction(GetDllLibPdf().PdfDocumentBase_SaveToPostScriptS,self.Ptr, intPtrstream)

