from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfFieldWidget(PdfField):
    """
    Represents base class for loaded fields.
    """

    @property
    def Name(self) -> str:
        """
        Gets the name of the field.
        :return: A string value specifying the name of the field.
        """
        GetDllLibPdf().PdfFieldWidget_get_Name.argtypes = [c_void_p]
        GetDllLibPdf().PdfFieldWidget_get_Name.restype = c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfFieldWidget_get_Name,self.Ptr))
        return ret

    @property
    def MappingName(self) -> str:
        """
        Gets or sets the mapping name to be used when exporting interactive form field data from the document.
        :return: A string value specifying the mapping name of the field.
        """
        GetDllLibPdf().PdfFieldWidget_get_MappingName.argtypes = [c_void_p]
        GetDllLibPdf().PdfFieldWidget_get_MappingName.restype = c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfFieldWidget_get_MappingName,self.Ptr))
        return ret

    @MappingName.setter
    def MappingName(self, value: str):
        GetDllLibPdf().PdfFieldWidget_set_MappingName.argtypes = [c_void_p, c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfFieldWidget_set_MappingName,self.Ptr, value)

    @property
    def ToolTip(self) -> str:
        """
        Gets or sets the tool tip.
        :return: A string value specifying the tool tip.
        """
        GetDllLibPdf().PdfFieldWidget_get_ToolTip.argtypes = [c_void_p]
        GetDllLibPdf().PdfFieldWidget_get_ToolTip.restype = c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfFieldWidget_get_ToolTip,self.Ptr))
        return ret

    @ToolTip.setter
    def ToolTip(self, value: str):
        GetDllLibPdf().PdfFieldWidget_set_ToolTip.argtypes = [c_void_p, c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfFieldWidget_set_ToolTip,self.Ptr, value)

    @property
    def Page(self) -> 'PdfPageBase':
        """
        Gets the page.
        :return: The page.
        """
        GetDllLibPdf().PdfFieldWidget_get_Page.argtypes = [c_void_p]
        GetDllLibPdf().PdfFieldWidget_get_Page.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfFieldWidget_get_Page,self.Ptr)
        ret = None if intPtr == None else PdfPageBase(intPtr)
        return ret

    @property
    def ReadOnly(self) -> bool:
        """
        Gets or sets a value indicating whether the field is read-only.
        :return: True if the field is read-only, false otherwise. Default is false.
        """
        GetDllLibPdf().PdfFieldWidget_get_ReadOnly.argtypes = [c_void_p]
        GetDllLibPdf().PdfFieldWidget_get_ReadOnly.restype = c_bool
        ret = CallCFunction(GetDllLibPdf().PdfFieldWidget_get_ReadOnly,self.Ptr)
        return ret

    @ReadOnly.setter
    def ReadOnly(self, value: bool):
        GetDllLibPdf().PdfFieldWidget_set_ReadOnly.argtypes = [c_void_p, c_bool]
        CallCFunction(GetDllLibPdf().PdfFieldWidget_set_ReadOnly,self.Ptr, value)

    @property
    def Required(self) -> bool:
        """
        Gets or sets a value indicating whether the field is required.
        :return: True if the field is required, false otherwise. Default is false.
        """
        GetDllLibPdf().PdfFieldWidget_get_Required.argtypes = [c_void_p]
        GetDllLibPdf().PdfFieldWidget_get_Required.restype = c_bool
        ret = CallCFunction(GetDllLibPdf().PdfFieldWidget_get_Required,self.Ptr)
        return ret

    @Required.setter
    def Required(self, value: bool):
        GetDllLibPdf().PdfFieldWidget_set_Required.argtypes = [c_void_p, c_bool]
        CallCFunction(GetDllLibPdf().PdfFieldWidget_set_Required,self.Ptr, value)

    @property
    def Export(self) -> bool:
        """
        Gets or sets a value indicating whether this is export.
        :return: True if export; otherwise, false.
        """
        GetDllLibPdf().PdfFieldWidget_get_Export.argtypes = [c_void_p]
        GetDllLibPdf().PdfFieldWidget_get_Export.restype = c_bool
        ret = CallCFunction(GetDllLibPdf().PdfFieldWidget_get_Export,self.Ptr)
        return ret

    @Export.setter
    def Export(self, value: bool):
        GetDllLibPdf().PdfFieldWidget_set_Export.argtypes = [c_void_p, c_bool]
        CallCFunction(GetDllLibPdf().PdfFieldWidget_set_Export,self.Ptr, value)

    @property
    def FormWidget(self) -> 'PdfFormWidget':
        """
        Gets the form.
        :return: The form.
        """
        GetDllLibPdf().PdfFieldWidget_get_FormWidget.argtypes = [c_void_p]
        GetDllLibPdf().PdfFieldWidget_get_FormWidget.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfFieldWidget_get_FormWidget,self.Ptr)
        ret = None if intPtr == None else PdfFormWidget(intPtr)
        return ret

    def ReSetPage(self, page: 'PdfPageBase'):
        """
        Re set the page.
        :param page: The page.
        """
        intPtrpage: c_void_p = page.Ptr
        GetDllLibPdf().PdfFieldWidget_ReSetPage.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfFieldWidget_ReSetPage,self.Ptr, intPtrpage)

    def SetName(self, name: str):
        """
        Sets the name of the field.
        :param name: New name of the field.
        """
        GetDllLibPdf().PdfFieldWidget_SetName.argtypes = [c_void_p, c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfFieldWidget_SetName,self.Ptr, name)

    def ObjectID(self) -> int:
        """
        Form field identifier.
        :return: The form field identifier.
        """
        GetDllLibPdf().PdfFieldWidget_ObjectID.argtypes = [c_void_p]
        GetDllLibPdf().PdfFieldWidget_ObjectID.restype = c_int
        ret = CallCFunction(GetDllLibPdf().PdfFieldWidget_ObjectID,self.Ptr)
        return ret