from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfGridCellContent(SpireObject):
    """
    Represents the content that can be written in a grid cell.
    """

    @property
    def ImageLocation(self) -> 'PointF':
        """
        Gets or sets the image location.
        """
        return None

    @ImageLocation.setter
    def ImageLocation(self, value: 'PointF'):
        """
        Sets the image location.
        """
        GetDllLibPdf().PdfGridCellContent_set_ImageLocation.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfGridCellContent_set_ImageLocation,self.Ptr, value.Ptr)

    @property
    def Text(self) -> str:
        """
        Gets or sets the text content.
        """
        GetDllLibPdf().PdfGridCellContent_get_Text.argtypes = [c_void_p]
        GetDllLibPdf().PdfGridCellContent_get_Text.restype = c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfGridCellContent_get_Text,self.Ptr))
        return ret

    @Text.setter
    def Text(self, value: str):
        """
        Sets the text content.
        """
        GetDllLibPdf().PdfGridCellContent_set_Text.argtypes = [c_void_p, c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfGridCellContent_set_Text,self.Ptr, value)

    @property
    def Brush(self) -> 'PdfBrush':
        """
        Gets or sets the brush.
        """
        GetDllLibPdf().PdfGridCellContent_get_Brush.argtypes = [c_void_p]
        GetDllLibPdf().PdfGridCellContent_get_Brush.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfGridCellContent_get_Brush,self.Ptr)
        ret = None if intPtr == None else PdfBrush(intPtr)
        return ret

    @Brush.setter
    def Brush(self, value: 'PdfBrush'):
        """
        Sets the brush.
        """
        GetDllLibPdf().PdfGridCellContent_set_Brush.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfGridCellContent_set_Brush,self.Ptr, value.Ptr)

    @property
    def Font(self) -> 'PdfFontBase':
        """
        Gets or sets the font.
        """
        GetDllLibPdf().PdfGridCellContent_get_Font.argtypes = [c_void_p]
        GetDllLibPdf().PdfGridCellContent_get_Font.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfGridCellContent_get_Font,self.Ptr)
        ret = None if intPtr == None else PdfFontBase(intPtr)
        return ret

    @Font.setter
    def Font(self, value: 'PdfFontBase'):
        """
        Sets the font.
        """
        GetDllLibPdf().PdfGridCellContent_set_Font.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfGridCellContent_set_Font,self.Ptr, value.Ptr)

    @property
    def Image(self) -> 'PdfImage':
        """
        Gets or sets the image.
        """
        GetDllLibPdf().PdfGridCellContent_get_Image.argtypes = [c_void_p]
        GetDllLibPdf().PdfGridCellContent_get_Image.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfGridCellContent_get_Image,self.Ptr)
        ret = None if intPtr == None else PdfImage(intPtr)
        return ret

    @Image.setter
    def Image(self, value: 'PdfImage'):
        """
        Sets the image.
        """
        GetDllLibPdf().PdfGridCellContent_set_Image.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfGridCellContent_set_Image,self.Ptr, value.Ptr)

    @property
    def ImageSize(self) -> 'SizeF':
        """
        Gets or sets the image size.
        """
        GetDllLibPdf().PdfGridCellContent_get_ImageSize.argtypes = [c_void_p]
        GetDllLibPdf().PdfGridCellContent_get_ImageSize.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfGridCellContent_get_ImageSize,self.Ptr)
        ret = None if intPtr == None else SizeF(intPtr)
        return ret

    @ImageSize.setter
    def ImageSize(self, value: 'SizeF'):
        """
        Sets the image size.
        """
        GetDllLibPdf().PdfGridCellContent_set_ImageSize.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfGridCellContent_set_ImageSize,self.Ptr, value.Ptr)

    @property
    def ImageNewline(self) -> bool:
        """
        Gets or sets the image newline.
        """
        GetDllLibPdf().PdfGridCellContent_get_ImageNewline.argtypes = [c_void_p]
        GetDllLibPdf().PdfGridCellContent_get_ImageNewline.restype = c_bool
        ret = CallCFunction(GetDllLibPdf().PdfGridCellContent_get_ImageNewline,self.Ptr)
        return ret

    @ImageNewline.setter
    def ImageNewline(self, value: bool):
        """
        Sets the image newline.
        """
        GetDllLibPdf().PdfGridCellContent_set_ImageNewline.argtypes = [c_void_p, c_bool]
        CallCFunction(GetDllLibPdf().PdfGridCellContent_set_ImageNewline,self.Ptr, value)

    @property
    def StringFormat(self) -> 'PdfStringFormat':
        """
        Gets or sets the string format.
        """
        GetDllLibPdf().PdfGridCellContent_get_StringFormat.argtypes = [c_void_p]
        GetDllLibPdf().PdfGridCellContent_get_StringFormat.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfGridCellContent_get_StringFormat,self.Ptr)
        ret = None if intPtr == None else PdfStringFormat(intPtr)
        return ret

    @StringFormat.setter
    def StringFormat(self, value: 'PdfStringFormat'):
        """
        Sets the string format.
        """
        GetDllLibPdf().PdfGridCellContent_set_StringFormat.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfGridCellContent_set_StringFormat,self.Ptr, value.Ptr)