from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfGridColumnCollection(IEnumerable):
    """
    Represents a collection of PdfGridColumn objects.
    """

    def get_Item(self, index: int) -> 'PdfGridColumn':
        """
        Gets the PdfGridColumn at the specified index.

        Args:
            index: The index of the PdfGridColumn.

        Returns:
            The PdfGridColumn at the specified index.
        """
        GetDllLibPdf().PdfGridColumnCollection_get_Item.argtypes = [c_void_p, c_int]
        GetDllLibPdf().PdfGridColumnCollection_get_Item.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfGridColumnCollection_get_Item,self.Ptr, index)
        ret = None if intPtr == None else PdfGridColumn(intPtr)
        return ret

    @property
    def Count(self) -> int:
        """
        Gets the count of PdfGridColumns in the collection.

        Returns:
            The count of PdfGridColumns.
        """
        GetDllLibPdf().PdfGridColumnCollection_get_Count.argtypes = [c_void_p]
        GetDllLibPdf().PdfGridColumnCollection_get_Count.restype = c_int
        ret = CallCFunction(GetDllLibPdf().PdfGridColumnCollection_get_Count,self.Ptr)
        return ret

    @dispatch
    def Add(self) -> PdfGridColumn:
        """
        Adds a new PdfGridColumn to the collection.

        Returns:
            The newly added PdfGridColumn.
        """
        GetDllLibPdf().PdfGridColumnCollection_Add.argtypes = [c_void_p]
        GetDllLibPdf().PdfGridColumnCollection_Add.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfGridColumnCollection_Add,self.Ptr)
        ret = None if intPtr == None else PdfGridColumn(intPtr)
        return ret

    @dispatch
    def Add(self, count: int):
        """
        Adds the specified number of PdfGridColumns to the collection.

        Args:
            count: The number of PdfGridColumns to add.
        """
        GetDllLibPdf().PdfGridColumnCollection_AddC.argtypes = [c_void_p, c_int]
        CallCFunction(GetDllLibPdf().PdfGridColumnCollection_AddC,self.Ptr, count)

    @dispatch
    def Add(self, column: PdfGridColumn):
        """
        Adds the specified PdfGridColumn to the collection.

        Args:
            column: The PdfGridColumn to add.
        """
        intPtrcolumn: c_void_p = column.Ptr

        GetDllLibPdf().PdfGridColumnCollection_AddC1.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfGridColumnCollection_AddC1,self.Ptr, intPtrcolumn)

    def Remove(self, item: 'PdfGridColumn') -> bool:
        """
        Removes the first occurrence of a specific PdfGridColumn from the collection.

        Args:
            item: The PdfGridColumn to remove.

        Returns:
            True if the PdfGridColumn is successfully removed, False otherwise.
        """
        intPtritem: c_void_p = item.Ptr

        GetDllLibPdf().PdfGridColumnCollection_Remove.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfGridColumnCollection_Remove.restype = c_bool
        ret = CallCFunction(GetDllLibPdf().PdfGridColumnCollection_Remove,self.Ptr, intPtritem)
        return ret

    def RemoveAt(self, index: int):
        """
        Removes the PdfGridColumn at the specified index from the collection.

        Args:
            index: The index of the PdfGridColumn to remove.
        """
        GetDllLibPdf().PdfGridColumnCollection_RemoveAt.argtypes = [c_void_p, c_int]
        CallCFunction(GetDllLibPdf().PdfGridColumnCollection_RemoveAt,self.Ptr, index)

    def GetEnumerator(self) -> 'IEnumerator':
        """
        Returns an enumerator that iterates through the collection.

        Returns:
            An IEnumerator object.
        """
        GetDllLibPdf().PdfGridColumnCollection_GetEnumerator.argtypes = [c_void_p]
        GetDllLibPdf().PdfGridColumnCollection_GetEnumerator.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfGridColumnCollection_GetEnumerator,self.Ptr)
        ret = None if intPtr == None else IEnumerator(intPtr)
        return ret