from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfJavaScriptAction(PdfAction):
    """
    Represents an action which performs java script action in pdf document.
    """
    @dispatch
    def __init__(self, javaScript: str):
        """
        Initializes a new instance of the PdfJavaScriptAction class.

        Args:
            javaScript: The javascript code to be executed when this action is executed.
        """
        GetDllLibPdf().PdfJavaScriptAction_CreatePdfJavaScriptActionJ.argtypes = [c_wchar_p]
        GetDllLibPdf().PdfJavaScriptAction_CreatePdfJavaScriptActionJ.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfJavaScriptAction_CreatePdfJavaScriptActionJ,javaScript)
        super(PdfJavaScriptAction, self).__init__(intPtr)

    @property
    def Script(self) -> str:
        """
        Gets or sets the javascript code to be executed when this action is executed.

        Returns:
            A string value representing valid javascript code to be executed.
        """
        GetDllLibPdf().PdfJavaScriptAction_get_Script.argtypes = [c_void_p]
        GetDllLibPdf().PdfJavaScriptAction_get_Script.restype = c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfJavaScriptAction_get_Script,self.Ptr))
        return ret

    @Script.setter
    def Script(self, value: str):
        """
        Sets the javascript code to be executed when this action is executed.

        Args:
            value: A string value representing valid javascript code to be executed.
        """
        GetDllLibPdf().PdfJavaScriptAction_set_Script.argtypes = [c_void_p, c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfJavaScriptAction_set_Script,self.Ptr, value)