from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfLabColorSpace(PdfColorSpaces):
    """
    Represents a Lab colorspace
    """

    @property
    def BlackPoint(self) -> List[float]:
        """
        Gets or sets BlackPoint

        Returns:
            List[float]: An array of three numbers [XB YB ZB] specifying the tristimulus value, in the CIE 1931 XYZ space, of the diffuse black point.
        """
        GetDllLibPdf().PdfLabColorSpace_get_BlackPoint.argtypes = [c_void_p]
        GetDllLibPdf().PdfLabColorSpace_get_BlackPoint.restype = IntPtrArray
        intPtrArray = CallCFunction(GetDllLibPdf().PdfLabColorSpace_get_BlackPoint,self.Ptr)
        ret = GetVectorFromArray(intPtrArray, c_double)
        return ret

    @BlackPoint.setter
    def BlackPoint(self, value: List[float]):
        """
        Sets the BlackPoint

        Args:
            value (List[float]): An array of three numbers [XB YB ZB] specifying the tristimulus value, in the CIE 1931 XYZ space, of the diffuse black point.
        """
        vCount = len(value)
        ArrayType = c_double * vCount
        vArray = ArrayType()
        for i in range(0, vCount):
            vArray[i] = value[i]
        GetDllLibPdf().PdfLabColorSpace_set_BlackPoint.argtypes = [c_void_p, ArrayType, c_int]
        CallCFunction(GetDllLibPdf().PdfLabColorSpace_set_BlackPoint,self.Ptr, vArray, vCount)

    @property
    def Range(self) -> List[float]:
        """
        Gets or sets the Range

        Returns:
            List[float]: An array of three numbers [XB YB ZB] specifying the tristimulus value, in the CIE 1931 XYZ space, of the diffuse black point.
        """
        GetDllLibPdf().PdfLabColorSpace_get_Range.argtypes = [c_void_p]
        GetDllLibPdf().PdfLabColorSpace_get_Range.restype = IntPtrArray
        intPtrArray = CallCFunction(GetDllLibPdf().PdfLabColorSpace_get_Range,self.Ptr)
        ret = GetVectorFromArray(intPtrArray, c_double)
        return ret

    @Range.setter
    def Range(self, value: List[float]):
        """
        Sets the Range

        Args:
            value (List[float]): An array of three numbers [XB YB ZB] specifying the tristimulus value, in the CIE 1931 XYZ space, of the diffuse black point.
        """
        vCount = len(value)
        ArrayType = c_double * vCount
        vArray = ArrayType()
        for i in range(0, vCount):
            vArray[i] = value[i]
        GetDllLibPdf().PdfLabColorSpace_set_Range.argtypes = [c_void_p, ArrayType, c_int]
        CallCFunction(GetDllLibPdf().PdfLabColorSpace_set_Range,self.Ptr, vArray, vCount)

    @property
    def WhitePoint(self) -> List[float]:
        """
        Gets or sets the white point

        Returns:
            List[float]: An array of three numbers [XW YW ZW] specifying the tristimulus value, in the CIE 1931 XYZ space, of the diffuse white point.
        """
        GetDllLibPdf().PdfLabColorSpace_get_WhitePoint.argtypes = [c_void_p]
        GetDllLibPdf().PdfLabColorSpace_get_WhitePoint.restype = IntPtrArray
        intPtrArray = CallCFunction(GetDllLibPdf().PdfLabColorSpace_get_WhitePoint,self.Ptr)
        ret = GetVectorFromArray(intPtrArray, c_double)
        return ret

    @WhitePoint.setter
    def WhitePoint(self, value: List[float]):
        """
        Sets the white point

        Args:
            value (List[float]): An array of three numbers [XW YW ZW] specifying the tristimulus value, in the CIE 1931 XYZ space, of the diffuse white point.
        """
        vCount = len(value)
        ArrayType = c_double * vCount
        vArray = ArrayType()
        for i in range(0, vCount):
            vArray[i] = value[i]
        GetDllLibPdf().PdfLabColorSpace_set_WhitePoint.argtypes = [c_void_p, ArrayType, c_int]
        CallCFunction(GetDllLibPdf().PdfLabColorSpace_set_WhitePoint,self.Ptr, vArray, vCount)