from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfLaunchAction(PdfAction):
    """
    Represents an action which launches an application or opens or prints a document.
    """

    @dispatch
    def __init__(self, filename: str):
        """
        Initializes a new instance of the PdfLaunchAction class with the specified filename.
        """
        GetDllLibPdf().PdfLaunchAction_CreatePdfLaunchActionF.argtypes = [c_wchar_p]
        GetDllLibPdf().PdfLaunchAction_CreatePdfLaunchActionF.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfLaunchAction_CreatePdfLaunchActionF,filename)
        super(PdfLaunchAction, self).__init__(intPtr)

    @dispatch
    def __init__(self, filename: str, path: PdfFilePathType):
        """
        Initializes a new instance of the PdfLaunchAction class with the specified filename and path.
        """
        enumType: c_int = path.value
        GetDllLibPdf().PdfLaunchAction_CreatePdfLaunchActionFP.argtypes = [c_wchar_p, c_int]
        GetDllLibPdf().PdfLaunchAction_CreatePdfLaunchActionFP.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfLaunchAction_CreatePdfLaunchActionFP,filename, enumType)
        super(PdfLaunchAction, self).__init__(intPtr)

    @property
    def FileName(self) -> str:
        """
        Gets or sets the file to be launched.
        """
        GetDllLibPdf().PdfLaunchAction_get_FileName.argtypes = [c_void_p]
        GetDllLibPdf().PdfLaunchAction_get_FileName.restype = c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfLaunchAction_get_FileName,self.Ptr))
        return ret

    @FileName.setter
    def FileName(self, value: str):
        """
        Sets the file to be launched.
        """
        GetDllLibPdf().PdfLaunchAction_set_FileName.argtypes = [c_void_p, c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfLaunchAction_set_FileName,self.Ptr, value)

    @property
    def IsNewWindow(self) -> bool:
        """
        Indicates whether the target document should be opened in a new window or not.
        """
        GetDllLibPdf().PdfLaunchAction_get_IsNewWindow.argtypes = [c_void_p]
        GetDllLibPdf().PdfLaunchAction_get_IsNewWindow.restype = c_bool
        ret = CallCFunction(GetDllLibPdf().PdfLaunchAction_get_IsNewWindow,self.Ptr)
        return ret

    @IsNewWindow.setter
    def IsNewWindow(self, value: bool):
        """
        Sets whether the target document should be opened in a new window or not.
        """
        GetDllLibPdf().PdfLaunchAction_set_IsNewWindow.argtypes = [c_void_p, c_bool]
        CallCFunction(GetDllLibPdf().PdfLaunchAction_set_IsNewWindow,self.Ptr, value)
