from enum import Enum
from plum import dispatch
from typing import TypeVar,Union,Generic,List,Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfMatrix (SpireObject) :
    """
    Represent the matrix
    """
    @property
    def OffsetX(self)->float:
        """
        Gets the x translation value (the dx value, or the element in the third row and first column).
        """
        GetDllLibPdf().PdfMatrix_get_OffsetX.argtypes=[c_void_p]
        GetDllLibPdf().PdfMatrix_get_OffsetX.restype=c_float
        ret = CallCFunction(GetDllLibPdf().PdfMatrix_get_OffsetX,self.Ptr)
        return ret

    @property
    def OffsetY(self)->float:
        """
        Gets the x translation value (the dx value, or the element in the third row and second column).
        """
        GetDllLibPdf().PdfMatrix_get_OffsetY.argtypes=[c_void_p]
        GetDllLibPdf().PdfMatrix_get_OffsetY.restype=c_float
        ret = CallCFunction(GetDllLibPdf().PdfMatrix_get_OffsetY,self.Ptr)
        return ret

    @property

    def Elements(self)->List[float]:
        """
        Gets an array of floating-point values that represents the elements.
        """
        GetDllLibPdf().PdfMatrix_get_Elements.argtypes=[c_void_p]
        GetDllLibPdf().PdfMatrix_get_Elements.restype=IntPtrArray
        intPtrArray = CallCFunction(GetDllLibPdf().PdfMatrix_get_Elements,self.Ptr)
        ret = GetVectorFromArray(intPtrArray, c_float)
        return ret

    @dispatch

    def Multiply(self ,matrix:'PdfMatrix'):
        """
        Prepend the specified matrix.

        Args:
            matrix (PdfMatrix): Matrix is to be multiplied.
        """		
        intPtrmatrix:c_void_p = matrix.Ptr

        GetDllLibPdf().PdfMatrix_Multiply.argtypes=[c_void_p ,c_void_p]
        CallCFunction(GetDllLibPdf().PdfMatrix_Multiply,self.Ptr, intPtrmatrix)

    @dispatch

    def Multiply(self ,matrix:'PdfMatrix',order:PdfMatrixOrder):
        """
        Apply the specified matrix by the specified order.

        Args:
            matrix (PdfMatrix): Matrix is to be multiplied.
			order (PdfMatrixOrder): Represent the applying order.
        """			
        intPtrmatrix:c_void_p = matrix.Ptr
        enumorder:c_int = order.value

        GetDllLibPdf().PdfMatrix_MultiplyMO.argtypes=[c_void_p ,c_void_p,c_int]
        CallCFunction(GetDllLibPdf().PdfMatrix_MultiplyMO,self.Ptr, intPtrmatrix,enumorder)

    @dispatch

    def Translate(self ,offsetX:float,offsetY:float):
        """
        Prepend the specified translation vector (offsetX and offsetY).

        Args:
            offsetX (float): The x value by which to translate.
			offsetY (float): The y value by which to translate.
        """        
        GetDllLibPdf().PdfMatrix_Translate.argtypes=[c_void_p ,c_float,c_float]
        CallCFunction(GetDllLibPdf().PdfMatrix_Translate,self.Ptr, offsetX,offsetY)

    @dispatch

    def Translate(self ,offsetX:float,offsetY:float,order:PdfMatrixOrder):
        """
        Apply the specified translation vector (offsetX and offsetY) by the specified order.

        Args:
            offsetX (float): The x value by which to translate.
			offsetY (float): The y value by which to translate.
			order (PdfMatrixOrder): Represent the applying order.
        """		
        enumorder:c_int = order.value

        GetDllLibPdf().PdfMatrix_TranslateOOO.argtypes=[c_void_p ,c_float,c_float,c_int]
        CallCFunction(GetDllLibPdf().PdfMatrix_TranslateOOO,self.Ptr, offsetX,offsetY,enumorder)

    @dispatch

    def Scale(self ,scaleX:float,scaleY:float):
        """
        Prepend the specified scale vector (scaleX and scaleY).

        Args:
            scaleX (float): The value by which to scale in the x-axis direction.
			scaleY (float): The value by which to scale in the y-axis direction.
        """        
        GetDllLibPdf().PdfMatrix_Scale.argtypes=[c_void_p ,c_float,c_float]
        CallCFunction(GetDllLibPdf().PdfMatrix_Scale,self.Ptr, scaleX,scaleY)

    @dispatch

    def Scale(self ,scaleX:float,scaleY:float,order:PdfMatrixOrder):
        """
        Apply the specified scale vector (scaleX and scaleY) by the specified order.

        Args:
            scaleX (float): The value by which to scale in the x-axis direction.
			scaleY (float): The value by which to scale in the y-axis direction.
			order (PdfMatrixOrder): Represent the applying order.
        """ 		
        enumorder:c_int = order.value

        GetDllLibPdf().PdfMatrix_ScaleSSO.argtypes=[c_void_p ,c_float,c_float,c_int]
        CallCFunction(GetDllLibPdf().PdfMatrix_ScaleSSO,self.Ptr, scaleX,scaleY,enumorder)

    @dispatch

    def Rotate(self ,angle:float):
        """
        Prepend a clockwise rotation(angle) around the origin.

        Args:
            angle (float): The angle of the rotation, in degrees.
        """         
        GetDllLibPdf().PdfMatrix_Rotate.argtypes=[c_void_p ,c_float]
        CallCFunction(GetDllLibPdf().PdfMatrix_Rotate,self.Ptr, angle)

    @dispatch

    def Rotate(self ,angle:float,order:PdfMatrixOrder):
        """
        Apply a clockwise rotation(angle) around the origin by the specified order.

        Args:
            angle (float): The angle of the rotation, in degrees.
			order (PdfMatrixOrder): Represent the applying order.
        """		
        enumorder:c_int = order.value

        GetDllLibPdf().PdfMatrix_RotateAO.argtypes=[c_void_p ,c_float,c_int]
        CallCFunction(GetDllLibPdf().PdfMatrix_RotateAO,self.Ptr, angle,enumorder)

    @dispatch

    def Skew(self ,angleX:float,angleY:float):
        """
        Prepend the specified skew angles(angleX angleY).

        Args:
            angleX (float): The angle of the rotation, in degrees.
			angleY (float): The vertical skew angle, in degrees.
        """        
        GetDllLibPdf().PdfMatrix_Skew.argtypes=[c_void_p ,c_float,c_float]
        CallCFunction(GetDllLibPdf().PdfMatrix_Skew,self.Ptr, angleX,angleY)

    @dispatch

    def Skew(self ,angleX:float,angleY:float,order:PdfMatrixOrder):
        """
        Prepend the specified skew angles(angleX angleY) by the specified order.

        Args:
            angleX (float): The horizontal skew angle, in degrees.
			angleY (float): The vertical skew angle, in degrees.
			order (PdfMatrixOrder): Represent the applying order.
        """   		
        enumorder:c_int = order.value

        GetDllLibPdf().PdfMatrix_SkewAAO.argtypes=[c_void_p ,c_float,c_float,c_int]
        CallCFunction(GetDllLibPdf().PdfMatrix_SkewAAO,self.Ptr, angleX,angleY,enumorder)

    @dispatch

    def Shear(self ,shearX:float,shearY:float):
        """
        Prepend the specified Shear vector (shearX and shearY).

        Args:
            shearX (float): The horizontal shear factor.
			shearY (float): The vertical shear factor.
        """        
        GetDllLibPdf().PdfMatrix_Shear.argtypes=[c_void_p ,c_float,c_float]
        CallCFunction(GetDllLibPdf().PdfMatrix_Shear,self.Ptr, shearX,shearY)

    @dispatch

    def Shear(self ,shearX:float,shearY:float,order:PdfMatrixOrder):
        """
        Apply the specified Shear vector (shearX and shearY) by the specified order.

        Args:
            shearX (float): The horizontal shear factor.
			shearY (float): The vertical shear factor.
			order (PdfMatrixOrder): Represent the applying order.
        """ 		
        enumorder:c_int = order.value

        GetDllLibPdf().PdfMatrix_ShearSSO.argtypes=[c_void_p ,c_float,c_float,c_int]
        CallCFunction(GetDllLibPdf().PdfMatrix_ShearSSO,self.Ptr, shearX,shearY,enumorder)

#
#    def TransformPoints(self ,pts:'PointF[]')->List['PointF']:
#        """
#    <summary>
#        Applies the geometric transform to a specified array of points.
#    </summary>
#    <param name="pt">An array of points to transform.</param>
#    <returns>The transformed points.</returns>
#        """
#        #arraypts:ArrayTypepts = ""
#        countpts = len(pts)
#        ArrayTypepts = c_void_p * countpts
#        arraypts = ArrayTypepts()
#        for i in range(0, countpts):
#            arraypts[i] = pts[i].Ptr
#
#
#        GetDllLibPdf().PdfMatrix_TransformPoints.argtypes=[c_void_p ,ArrayTypepts]
#        GetDllLibPdf().PdfMatrix_TransformPoints.restype=IntPtrArray
#        intPtrArray = CallCFunction(GetDllLibPdf().PdfMatrix_TransformPoints,self.Ptr, arraypts)
#        ret = GetObjVectorFromArray(intPtrArray, PointF)
#        return ret



    def Clone(self)->'PdfMatrix':
        """

        """
        GetDllLibPdf().PdfMatrix_Clone.argtypes=[c_void_p]
        GetDllLibPdf().PdfMatrix_Clone.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfMatrix_Clone,self.Ptr)
        ret = None if intPtr==None else PdfMatrix(intPtr)
        return ret



    def DegreeToRadian(self ,degree:float)->float:
        """
        Converts degree to radian.

        Args:
            degree (float): The degree.
			
        Returns:
            float: The radian.
        """        
        GetDllLibPdf().PdfMatrix_DegreeToRadian.argtypes=[c_void_p ,c_double]
        GetDllLibPdf().PdfMatrix_DegreeToRadian.restype=c_double
        ret = CallCFunction(GetDllLibPdf().PdfMatrix_DegreeToRadian,self.Ptr, degree)
        return ret

