from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfPolyLineAnnotation(PdfAnnotation):
    """
    Represents the poly line annotation.
    """

    @dispatch
    def __init__(self, page: PdfPageBase, points: List[PointF]):
        """
        Initializes a new instance of the PdfPolyLineAnnotation class.

        Args:
            page (PdfPageBase): The page to which the annotation belongs.
            points (List[PointF]): The points that define the vertices of the poly line.
        """
        ptrPage: c_void_p = page.Ptr

        countnewValues = len(points)
        ArrayTypenewValues = c_void_p * countnewValues
        arraynewValues = ArrayTypenewValues()
        for i in range(0, countnewValues):
            arraynewValues[i] = points[i].Ptr

        GetDllLibPdf().PdfPolyLineAnnotation_CreatePdfPolyLineAnnotationPP.argtypes = [c_void_p, ArrayTypenewValues, c_int]
        GetDllLibPdf().PdfPolyLineAnnotation_CreatePdfPolyLineAnnotationPP.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfPolyLineAnnotation_CreatePdfPolyLineAnnotationPP,ptrPage, arraynewValues, countnewValues)
        super(PdfPolyLineAnnotation, self).__init__(intPtr)

    @property
    def Author(self) -> str:
        """
        Gets or sets the user who created the annotation.
        """
        GetDllLibPdf().PdfPolyLineAnnotation_get_Author.argtypes = [c_void_p]
        GetDllLibPdf().PdfPolyLineAnnotation_get_Author.restype = c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfPolyLineAnnotation_get_Author,self.Ptr))
        return ret

    @Author.setter
    def Author(self, value: str):
        """
        Sets the user who created the annotation.

        Args:
            value (str): The user who created the annotation.
        """
        GetDllLibPdf().PdfPolyLineAnnotation_set_Author.argtypes = [c_void_p, c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfPolyLineAnnotation_set_Author,self.Ptr, value)

    @property
    def Subject(self) -> str:
        """
        Gets or sets the description of the annotation.
        """
        GetDllLibPdf().PdfPolyLineAnnotation_get_Subject.argtypes = [c_void_p]
        GetDllLibPdf().PdfPolyLineAnnotation_get_Subject.restype = c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfPolyLineAnnotation_get_Subject,self.Ptr))
        return ret

    @Subject.setter
    def Subject(self, value: str):
        """
        Sets the description of the annotation.

        Args:
            value (str): The description of the annotation.
        """
        GetDllLibPdf().PdfPolyLineAnnotation_set_Subject.argtypes = [c_void_p, c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfPolyLineAnnotation_set_Subject,self.Ptr, value)
