from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfPopupAnnotation(PdfAnnotation):
    """
    Represents a Base class for popup annotation which can be either in open or closed state.
    """

    @dispatch
    def __init__(self):
        """
        Initializes a new instance of the PdfPopupAnnotation class.
        """
        GetDllLibPdf().PdfPopupAnnotation_CreatePdfPopupAnnotation.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfPopupAnnotation_CreatePdfPopupAnnotation)
        super(PdfPopupAnnotation, self).__init__(intPtr)

    @dispatch
    def __init__(self, rectangle: RectangleF):
        """
        Initializes a new instance of the PdfPopupAnnotation class with the specified rectangle.
        
        Args:
            rectangle: The rectangle of the annotation.
        """
        ptrRec: c_void_p = rectangle.Ptr

        GetDllLibPdf().PdfPopupAnnotation_CreatePdfPopupAnnotationR.argtypes = [c_void_p]
        GetDllLibPdf().PdfPopupAnnotation_CreatePdfPopupAnnotationR.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfPopupAnnotation_CreatePdfPopupAnnotationR,ptrRec)
        super(PdfPopupAnnotation, self).__init__(intPtr)

    @dispatch
    def __init__(self, rectangle: RectangleF, text: str):
        """
        Initializes a new instance of the PdfPopupAnnotation class with the specified rectangle and text.
        
        Args:
            rectangle: The rectangle of the annotation.
            text: The text of the annotation.
        """
        ptrRec: c_void_p = rectangle.Ptr

        GetDllLibPdf().PdfPopupAnnotation_CreatePdfPopupAnnotationRT.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().PdfPopupAnnotation_CreatePdfPopupAnnotationRT.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfPopupAnnotation_CreatePdfPopupAnnotationRT,ptrRec, text)
        super(PdfPopupAnnotation, self).__init__(intPtr)

    @property
    def Icon(self) -> 'PdfPopupIcon':
        """
        Gets or sets the icon style of the annotation.
        """
        GetDllLibPdf().PdfPopupAnnotation_get_Icon.argtypes = [c_void_p]
        GetDllLibPdf().PdfPopupAnnotation_get_Icon.restype = c_int
        ret = CallCFunction(GetDllLibPdf().PdfPopupAnnotation_get_Icon,self.Ptr)
        objwrapped = PdfPopupIcon(ret)
        return objwrapped

    @Icon.setter
    def Icon(self, value: 'PdfPopupIcon'):
        """
        Sets the icon style of the annotation.
        
        Args:
            value: The icon style to set.
        """
        GetDllLibPdf().PdfPopupAnnotation_set_Icon.argtypes = [c_void_p, c_int]
        CallCFunction(GetDllLibPdf().PdfPopupAnnotation_set_Icon,self.Ptr, value.value)

    @property
    def Open(self) -> bool:
        """
        Gets or sets a value indicating whether the annotation is initially open or closed.
        """
        GetDllLibPdf().PdfPopupAnnotation_get_Open.argtypes = [c_void_p]
        GetDllLibPdf().PdfPopupAnnotation_get_Open.restype = c_bool
        ret = CallCFunction(GetDllLibPdf().PdfPopupAnnotation_get_Open,self.Ptr)
        return ret

    @Open.setter
    def Open(self, value: bool):
        """
        Sets a value indicating whether the annotation is initially open or closed.
        
        Args:
            value: The value to set.
        """
        GetDllLibPdf().PdfPopupAnnotation_set_Open.argtypes = [c_void_p, c_bool]
        CallCFunction(GetDllLibPdf().PdfPopupAnnotation_set_Open,self.Ptr, value)

    @property
    def Appearance(self) -> 'PdfAppearance':
        """
        Gets or sets the appearance of the annotation.
        """
        GetDllLibPdf().PdfPopupAnnotation_get_Appearance.argtypes = [c_void_p]
        GetDllLibPdf().PdfPopupAnnotation_get_Appearance.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfPopupAnnotation_get_Appearance,self.Ptr)
        ret = None if intPtr == None else PdfAppearance(intPtr)
        return ret

    @Appearance.setter
    def Appearance(self, value: 'PdfAppearance'):
        """
        Sets the appearance of the annotation.
        
        Args:
            value: The appearance to set.
        """
        GetDllLibPdf().PdfPopupAnnotation_set_Appearance.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfPopupAnnotation_set_Appearance,self.Ptr, value.Ptr)

