from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfPopupAnnotationWidget(PdfStyledAnnotationWidget):
    """
    Represents the loaded pop up annotation class.
    """

    @property
    def Open(self) -> bool:
        """
        Gets or sets the open option of the popup annotation.
        """
        GetDllLibPdf().PdfPopupAnnotationWidget_get_Open.argtypes = [c_void_p]
        GetDllLibPdf().PdfPopupAnnotationWidget_get_Open.restype = c_bool
        ret = CallCFunction(GetDllLibPdf().PdfPopupAnnotationWidget_get_Open,self.Ptr)
        return ret

    @Open.setter
    def Open(self, value: bool):
        """
        Sets the open option of the popup annotation.
        """
        GetDllLibPdf().PdfPopupAnnotationWidget_set_Open.argtypes = [c_void_p, c_bool]
        CallCFunction(GetDllLibPdf().PdfPopupAnnotationWidget_set_Open,self.Ptr, value)

    @property
    def Icon(self) -> 'PdfPopupIcon':
        """
        Gets or sets the icon of the annotation.
        """
        GetDllLibPdf().PdfPopupAnnotationWidget_get_Icon.argtypes = [c_void_p]
        GetDllLibPdf().PdfPopupAnnotationWidget_get_Icon.restype = c_int
        ret = CallCFunction(GetDllLibPdf().PdfPopupAnnotationWidget_get_Icon,self.Ptr)
        objwrapped = PdfPopupIcon(ret)
        return objwrapped

    @Icon.setter
    def Icon(self, value: 'PdfPopupIcon'):
        """
        Sets the icon of the annotation.
        """
        GetDllLibPdf().PdfPopupAnnotationWidget_set_Icon.argtypes = [c_void_p, c_int]
        CallCFunction(GetDllLibPdf().PdfPopupAnnotationWidget_set_Icon,self.Ptr, value.value)

    def ObjectID(self) -> int:
        """
        Represents the Form field identifier.
        """
        GetDllLibPdf().PdfPopupAnnotationWidget_ObjectID.argtypes = [c_void_p]
        GetDllLibPdf().PdfPopupAnnotationWidget_ObjectID.restype = c_int
        ret = CallCFunction(GetDllLibPdf().PdfPopupAnnotationWidget_ObjectID,self.Ptr)
        return ret