from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfRubberStampAnnotation(PdfAnnotation):
    """
    Represents the Rubber Stamp annotation for a PDF document.
    """

    @dispatch
    def __init__(self):
        """
        Initializes a new instance of the PdfRubberStampAnnotation class.
        """
        GetDllLibPdf().PdfRubberStampAnnotation_CreatePdfRubberStampAnnotation.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfRubberStampAnnotation_CreatePdfRubberStampAnnotation)
        super(PdfRubberStampAnnotation, self).__init__(intPtr)

    @dispatch
    def __init__(self, rectangle: RectangleF):
        """
        Initializes a new instance of the PdfRubberStampAnnotation class with the specified rectangle.
        
        :param rectangle: The rectangle of the annotation.
        """
        ptrRec: c_void_p = rectangle.Ptr

        GetDllLibPdf().PdfRubberStampAnnotation_CreatePdfRubberStampAnnotationR.argtypes = [c_void_p]
        GetDllLibPdf().PdfRubberStampAnnotation_CreatePdfRubberStampAnnotationR.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfRubberStampAnnotation_CreatePdfRubberStampAnnotationR,ptrRec)
        super(PdfRubberStampAnnotation, self).__init__(intPtr)

    @dispatch
    def __init__(self, rectangle: RectangleF, text: str):
        """
        Initializes a new instance of the PdfRubberStampAnnotation class with the specified rectangle and text.
        
        :param rectangle: The rectangle of the annotation.
        :param text: The text of the annotation.
        """
        ptrRec: c_void_p = rectangle.Ptr

        GetDllLibPdf().PdfRubberStampAnnotation_CreatePdfRubberStampAnnotationRT.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().PdfRubberStampAnnotation_CreatePdfRubberStampAnnotationRT.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfRubberStampAnnotation_CreatePdfRubberStampAnnotationRT,ptrRec, text)
        super(PdfRubberStampAnnotation, self).__init__(intPtr)

    @property
    def Icon(self) -> 'PdfRubberStampAnnotationIcon':
        """
        Gets or sets the annotation's icon.
        
        :return: A enumeration member specifying the icon for the annotation when it is displayed in closed state.
        """
        GetDllLibPdf().PdfRubberStampAnnotation_get_Icon.argtypes = [c_void_p]
        GetDllLibPdf().PdfRubberStampAnnotation_get_Icon.restype = c_int
        ret = CallCFunction(GetDllLibPdf().PdfRubberStampAnnotation_get_Icon,self.Ptr)
        objwrapped = PdfRubberStampAnnotationIcon(ret)
        return objwrapped

    @Icon.setter
    def Icon(self, value: 'PdfRubberStampAnnotationIcon'):
        """
        Sets the annotation's icon.
        
        :param value: A enumeration member specifying the icon for the annotation when it is displayed in closed state.
        """
        GetDllLibPdf().PdfRubberStampAnnotation_set_Icon.argtypes = [c_void_p, c_int]
        CallCFunction(GetDllLibPdf().PdfRubberStampAnnotation_set_Icon,self.Ptr, value.value)

    @property
    def Appearance(self) -> 'PdfAppearance':
        """
        Gets or sets appearance of the annotation.
        
        :return: The appearance of the annotation.
        """
        GetDllLibPdf().PdfRubberStampAnnotation_get_Appearance.argtypes = [c_void_p]
        GetDllLibPdf().PdfRubberStampAnnotation_get_Appearance.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfRubberStampAnnotation_get_Appearance,self.Ptr)
        ret = None if intPtr == None else PdfAppearance(intPtr)
        return ret

    @Appearance.setter
    def Appearance(self, value: 'PdfAppearance'):
        """
        Sets the appearance of the annotation.
        
        :param value: The appearance of the annotation.
        """
        GetDllLibPdf().PdfRubberStampAnnotation_set_Appearance.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfRubberStampAnnotation_set_Appearance,self.Ptr, value.Ptr)

    @property
    def Author(self) -> str:
        """
        Gets or set the name of the annotation,the entry is deleted by default when the input value is an empty string.
        
        :return: The name of the annotation.
        """
        GetDllLibPdf().PdfRubberStampAnnotation_get_Author.argtypes = [c_void_p]
        GetDllLibPdf().PdfRubberStampAnnotation_get_Author.restype = c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfRubberStampAnnotation_get_Author,self.Ptr))
        return ret

    @Author.setter
    def Author(self, value: str):
        """
        Sets the name of the annotation.
        
        :param value: The name of the annotation.
        """
        GetDllLibPdf().PdfRubberStampAnnotation_set_Author.argtypes = [c_void_p, c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfRubberStampAnnotation_set_Author,self.Ptr, value)

    @property
    def Subject(self) -> str:
        """
        Gets or sets the annotation's subject.
        
        :return: The subject of the annotation.
        """
        GetDllLibPdf().PdfRubberStampAnnotation_get_Subject.argtypes = [c_void_p]
        GetDllLibPdf().PdfRubberStampAnnotation_get_Subject.restype = c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfRubberStampAnnotation_get_Subject,self.Ptr))
        return ret

    @Subject.setter
    def Subject(self, value: str):
        """
        Sets the annotation's subject.
        
        :param value: The subject of the annotation.
        """
        GetDllLibPdf().PdfRubberStampAnnotation_set_Subject.argtypes = [c_void_p, c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfRubberStampAnnotation_set_Subject,self.Ptr, value)

    @property
    def CreationDate(self) -> 'DateTime':
        """
        Gets or sets the creation date.
        
        :return: The creation date of the annotation.
        """
        GetDllLibPdf().PdfRubberStampAnnotation_get_CreationDate.argtypes = [c_void_p]
        GetDllLibPdf().PdfRubberStampAnnotation_get_CreationDate.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfRubberStampAnnotation_get_CreationDate,self.Ptr)
        ret = None if intPtr == None else DateTime(intPtr)
        return ret

    @CreationDate.setter
    def CreationDate(self, value: 'DateTime'):
        """
        Sets the creation date of the annotation.
        
        :param value: The creation date of the annotation.
        """
        GetDllLibPdf().PdfRubberStampAnnotation_set_CreationDate.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfRubberStampAnnotation_set_CreationDate,self.Ptr, value.Ptr)