from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfSectionNumberField(PdfMultipleNumberValueField):
    """
    Represents a section number field in a PDF document.
    """

    @dispatch
    def __init__(self):
        """
        Initializes a new instance of the PdfSectionNumberField class.
        """
        GetDllLibPdf().PdfSectionNumberField_CreatePdfSectionNumberField.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfSectionNumberField_CreatePdfSectionNumberField)
        super(PdfSectionNumberField, self).__init__(intPtr)

    @dispatch
    def __init__(self, font: PdfFontBase):
        """
        Initializes a new instance of the PdfSectionNumberField class with the specified font.
        
        Args:
            font (PdfFontBase): The font to use for the section number field.
        """
        ptrFont: c_void_p = font.Ptr
        GetDllLibPdf().PdfSectionNumberField_CreatePdfSectionNumberFieldF.argtypes = [c_void_p]
        GetDllLibPdf().PdfSectionNumberField_CreatePdfSectionNumberFieldF.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfSectionNumberField_CreatePdfSectionNumberFieldF,ptrFont)
        super(PdfSectionNumberField, self).__init__(intPtr)

    @dispatch
    def __init__(self, font: PdfFontBase, brush: PdfBrush):
        """
        Initializes a new instance of the PdfSectionNumberField class with the specified font and brush.
        
        Args:
            font (PdfFontBase): The font to use for the section number field.
            brush (PdfBrush): The brush to use for the section number field.
        """
        ptrFont: c_void_p = font.Ptr
        ptrBrush: c_void_p = brush.Ptr
        GetDllLibPdf().PdfSectionNumberField_CreatePdfSectionNumberFieldFB.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfSectionNumberField_CreatePdfSectionNumberFieldFB.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfSectionNumberField_CreatePdfSectionNumberFieldFB,ptrFont, ptrBrush)
        super(PdfSectionNumberField, self).__init__(intPtr)

    @dispatch
    def __init__(self, font: PdfFontBase, bounds: RectangleF):
        """
        Initializes a new instance of the PdfSectionNumberField class with the specified font and bounds.
        
        Args:
            font (PdfFontBase): The font to use for the section number field.
            bounds (RectangleF): The bounds of the section number field.
        """
        ptrFont: c_void_p = font.Ptr
        ptrBounds: c_void_p = bounds.Ptr
        GetDllLibPdf().PdfSectionNumberField_CreatePdfSectionNumberFieldFBs.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfSectionNumberField_CreatePdfSectionNumberFieldFBs.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfSectionNumberField_CreatePdfSectionNumberFieldFBs,ptrFont, ptrBounds)
        super(PdfSectionNumberField, self).__init__(intPtr)