from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfSignature(SpireObject):
    """
    The pdf signature.
    """

    @property
    def Filter(self) -> str:
        """
        The name of the preferred signature handler to use when validating this signature.
        """
        GetDllLibPdf().PdfSignature_get_Filter.argtypes = [c_void_p]
        GetDllLibPdf().PdfSignature_get_Filter.restype = c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfSignature_get_Filter,self.Ptr))
        return ret

    @property
    def SubFilter(self) -> str:
        """
        A name that describes the encoding of the signature value.
        """
        GetDllLibPdf().PdfSignature_get_SubFilter.argtypes = [c_void_p]
        GetDllLibPdf().PdfSignature_get_SubFilter.restype = c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfSignature_get_SubFilter,self.Ptr))
        return ret

    @property
    def Name(self) -> str:
        """
        The name of the person or authority signing the document.
        This value should be used only when it is not possible to extract the name from the signature,
        for example, from the certificate of the signer.
        """
        GetDllLibPdf().PdfSignature_get_Name.argtypes = [c_void_p]
        GetDllLibPdf().PdfSignature_get_Name.restype = c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfSignature_get_Name,self.Ptr))
        return ret

    @Name.setter
    def Name(self, value: str):
        GetDllLibPdf().PdfSignature_set_Name.argtypes = [c_void_p, c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfSignature_set_Name,self.Ptr, value)

    @property
    def Location(self) -> str:
        """
        Gets or sets the physical location of the signing.
        """
        GetDllLibPdf().PdfSignature_get_Location.argtypes = [c_void_p]
        GetDllLibPdf().PdfSignature_get_Location.restype = c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfSignature_get_Location,self.Ptr))
        return ret

    @Location.setter
    def Location(self, value: str):
        GetDllLibPdf().PdfSignature_set_Location.argtypes = [c_void_p, c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfSignature_set_Location,self.Ptr, value)

    @property
    def Reason(self) -> str:
        """
        Gets or sets reason of signing.
        The reason for the signing, such as "I agree...".
        """
        GetDllLibPdf().PdfSignature_get_Reason.argtypes = [c_void_p]
        GetDllLibPdf().PdfSignature_get_Reason.restype = c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfSignature_get_Reason,self.Ptr))
        return ret

    @Reason.setter
    def Reason(self, value: str):
        GetDllLibPdf().PdfSignature_set_Reason.argtypes = [c_void_p, c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfSignature_set_Reason,self.Ptr, value)

    @property
    def ContactInfo(self) -> str:
        """
        Gets or sets a phone number of signer.
        Information provided by the signer to enable a recipient to contact the signer to verify the signature;
        for example, a phone number.
        """
        GetDllLibPdf().PdfSignature_get_ContactInfo.argtypes = [c_void_p]
        GetDllLibPdf().PdfSignature_get_ContactInfo.restype = c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfSignature_get_ContactInfo,self.Ptr))
        return ret

    @ContactInfo.setter
    def ContactInfo(self, value: str):
        GetDllLibPdf().PdfSignature_set_ContactInfo.argtypes = [c_void_p, c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfSignature_set_ContactInfo,self.Ptr, value)