from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfSignatureProperties(SpireObject):
    """
    Signature properties.
    """

    def SetFilter(self, filter: str):
        """
        Set the name of the preferred signature handler to use when validating this signature.
        (Required)

        Args:
            filter: The name of the preferred signature handler.
        """
        GetDllLibPdf().PdfSignatureProperties_SetFilter.argtypes = [c_void_p, c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfSignatureProperties_SetFilter,self.Ptr, filter)

    def SetSubFilter(self, subFilter: str):
        """
        Set a name that describes the encoding of the signature value.
        (Required)

        Args:
            subFilter: A name that describes the encoding of the signature value.
        """
        GetDllLibPdf().PdfSignatureProperties_SetSubFilter.argtypes = [c_void_p, c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfSignatureProperties_SetSubFilter,self.Ptr, subFilter)

    def SetSignatureLength(self, signatureLength: 'UInt32'):
        """
        Set signature length.
        (Option)
        Default, signature need to call twice "Sign" method, one is to calculate signature length.
        If the signature length is known, avoid to calculate signature length by "Sign" method.
        The signature length.

        Args:
            signatureLength: The signature length.
        """
        intPtrsignatureLength: c_void_p = signatureLength.Ptr

        GetDllLibPdf().PdfSignatureProperties_SetSignatureLength.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfSignatureProperties_SetSignatureLength,self.Ptr, intPtrsignatureLength)

    def SetSoftwareModuleName(self, softwareModuleName: str):
        """
        Set the name of the software module used to create the signature.
        (Option)

        Args:
            softwareModuleName: The name of the software module.
        """
        GetDllLibPdf().PdfSignatureProperties_SetSoftwareModuleName.argtypes = [c_void_p, c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfSignatureProperties_SetSoftwareModuleName,self.Ptr, softwareModuleName)