from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfSolidBrush(PdfBrush):
    """
    Represents a brush that fills any object with a solid colour.
    """

    @dispatch
    def __init__(self, color: PdfRGBColor):
        """
        Initializes a new instance of the PdfSolidBrush class with the specified RGB color.

        Args:
            color: The RGB color of the brush.
        """
        ptrColor: c_void_p = color.Ptr
        GetDllLibPdf().PdfSolidBrush_CreatePdfSolidBrushRC.argtypes = [c_void_p]
        GetDllLibPdf().PdfSolidBrush_CreatePdfSolidBrushRC.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfSolidBrush_CreatePdfSolidBrushRC,ptrColor)
        super(PdfSolidBrush, self).__init__(intPtr)

    @dispatch
    def __init__(self, color: PdfComplexColor):
        """
        Initializes a new instance of the PdfSolidBrush class with the specified complex color.

        Args:
            color: The complex color of the brush.
        """
        ptrColor: c_void_p = color.Ptr
        GetDllLibPdf().PdfSolidBrush_CreatePdfSolidBrushCC.argtypes = [c_void_p]
        GetDllLibPdf().PdfSolidBrush_CreatePdfSolidBrushCC.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfSolidBrush_CreatePdfSolidBrushCC,ptrColor)
        super(PdfSolidBrush, self).__init__(intPtr)

    @property
    def Color(self) -> 'PdfRGBColor':
        """
        Gets or sets the color of the brush.

        Returns:
            The color of the brush.
        """
        GetDllLibPdf().PdfSolidBrush_get_Color.argtypes = [c_void_p]
        GetDllLibPdf().PdfSolidBrush_get_Color.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfSolidBrush_get_Color,self.Ptr)
        ret = None if intPtr == None else PdfRGBColor(intPtr)
        return ret

    @Color.setter
    def Color(self, value: 'PdfRGBColor'):
        """
        Sets the color of the brush.

        Args:
            value: The color to set.
        """
        GetDllLibPdf().PdfSolidBrush_set_Color.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfSolidBrush_set_Color,self.Ptr, value.Ptr)

    def Clone(self) -> 'PdfBrush':
        """
        Creates a new copy of the brush.

        Returns:
            A new instance of the Brush class.
        """
        GetDllLibPdf().PdfSolidBrush_Clone.argtypes = [c_void_p]
        GetDllLibPdf().PdfSolidBrush_Clone.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfSolidBrush_Clone,self.Ptr)
        ret = None if intPtr == None else PdfBrush(intPtr)
        return ret