from enum import Enum
from plum import dispatch
from typing import TypeVar,Union,Generic,List,Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfStandardStructTypes (SpireObject) :
    """
    Represents the standard struct types.
    """
    @staticmethod

    def Document()->str:
        """
        A complete document. This is the root element of any structure tree containing multiple parts or multiple articles.
        """
        #GetDllLibPdf().PdfStandardStructTypes_Document.argtypes=[]
        GetDllLibPdf().PdfStandardStructTypes_Document.restype=c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfStandardStructTypes_Document,))
        return ret


    @staticmethod

    def Part()->str:
        """
        A large-scale division of a document. This type of element is appropriate for grouping articles or sections.
        """
        #GetDllLibPdf().PdfStandardStructTypes_Part.argtypes=[]
        GetDllLibPdf().PdfStandardStructTypes_Part.restype=c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfStandardStructTypes_Part,))
        return ret


    @staticmethod

    def Article()->str:
        """
        A relatively self-contained body of text constituting a single narrative or exposition. Articles should be disjoint; 
            that is, they should not contain other articles as constituent elements.
        """
        #GetDllLibPdf().PdfStandardStructTypes_Article.argtypes=[]
        GetDllLibPdf().PdfStandardStructTypes_Article.restype=c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfStandardStructTypes_Article,))
        return ret


    @staticmethod

    def Section()->str:
        """
        A container for grouping related content elements. For example, a section might contain a heading, several introductory
            paragraphs, and two or more other sections nested within it as subsections.
        """
        #GetDllLibPdf().PdfStandardStructTypes_Section.argtypes=[]
        GetDllLibPdf().PdfStandardStructTypes_Section.restype=c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfStandardStructTypes_Section,))
        return ret


    @staticmethod

    def Division()->str:
        """
        A generic block-level element or group of elements.
        """
        #GetDllLibPdf().PdfStandardStructTypes_Division.argtypes=[]
        GetDllLibPdf().PdfStandardStructTypes_Division.restype=c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfStandardStructTypes_Division,))
        return ret


    @staticmethod

    def BlockQuote()->str:
        """
        A portion of text consisting of one or more paragraphs attributed to someone other than the author of the surrounding text.
        """
        #GetDllLibPdf().PdfStandardStructTypes_BlockQuote.argtypes=[]
        GetDllLibPdf().PdfStandardStructTypes_BlockQuote.restype=c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfStandardStructTypes_BlockQuote,))
        return ret


    @staticmethod

    def Caption()->str:
        """
        A brief portion of text describing a table or figure.
        """
        #GetDllLibPdf().PdfStandardStructTypes_Caption.argtypes=[]
        GetDllLibPdf().PdfStandardStructTypes_Caption.restype=c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfStandardStructTypes_Caption,))
        return ret


    @staticmethod

    def TOC()->str:
        """
        A list made up of table of contents item entries and/or other nested table of contents entries.
        """
        #GetDllLibPdf().PdfStandardStructTypes_TOC.argtypes=[]
        GetDllLibPdf().PdfStandardStructTypes_TOC.restype=c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfStandardStructTypes_TOC,))
        return ret


    @staticmethod

    def TOCI()->str:
        """
        An individual member of a table of contents.
        """
        #GetDllLibPdf().PdfStandardStructTypes_TOCI.argtypes=[]
        GetDllLibPdf().PdfStandardStructTypes_TOCI.restype=c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfStandardStructTypes_TOCI,))
        return ret


    @staticmethod

    def Index()->str:
        """
        A sequence of entries containing identifying text accompanied by reference elements
            that point out occurrences of the specified text in the main body of a document.
        """
        #GetDllLibPdf().PdfStandardStructTypes_Index.argtypes=[]
        GetDllLibPdf().PdfStandardStructTypes_Index.restype=c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfStandardStructTypes_Index,))
        return ret


    @staticmethod

    def NonStruct()->str:
        """
        A grouping element having no inherent structural significance; it serves solely for grouping purposes. 
            This type of element differs from a division (structure type Div) in that it is not interpreted 
            or exported to other document formats; however, its descendants are to be processed normally.
        """
        #GetDllLibPdf().PdfStandardStructTypes_NonStruct.argtypes=[]
        GetDllLibPdf().PdfStandardStructTypes_NonStruct.restype=c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfStandardStructTypes_NonStruct,))
        return ret


    @staticmethod

    def Private()->str:
        """
        A grouping element containing private content belonging to the application producing it. 
            The structural significance of this type of element is unspecified and is determined entirely by the producer application. 
            Neither the Private element nor any of its descendants are to be interpreted or exported to other document formats.
        """
        #GetDllLibPdf().PdfStandardStructTypes_Private.argtypes=[]
        GetDllLibPdf().PdfStandardStructTypes_Private.restype=c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfStandardStructTypes_Private,))
        return ret


    @staticmethod

    def Heading()->str:
        """
        A label for a subdivision of a document’s content. It should be the first child of the division that it heads.
        """
        #GetDllLibPdf().PdfStandardStructTypes_Heading.argtypes=[]
        GetDllLibPdf().PdfStandardStructTypes_Heading.restype=c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfStandardStructTypes_Heading,))
        return ret


    @staticmethod

    def HeadingLevel1()->str:
        """
        Headings with specific levels, for use in applications that cannot hierarchically nest their sections and thus 
            cannot determine the level of a heading from its level of nesting.
        """
        #GetDllLibPdf().PdfStandardStructTypes_HeadingLevel1.argtypes=[]
        GetDllLibPdf().PdfStandardStructTypes_HeadingLevel1.restype=c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfStandardStructTypes_HeadingLevel1,))
        return ret


    @staticmethod

    def HeadingLevel2()->str:
        """
        Headings with specific levels, for use in applications that cannot hierarchically nest their sections and thus 
            cannot determine the level of a heading from its level of nesting.
        """
        #GetDllLibPdf().PdfStandardStructTypes_HeadingLevel2.argtypes=[]
        GetDllLibPdf().PdfStandardStructTypes_HeadingLevel2.restype=c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfStandardStructTypes_HeadingLevel2,))
        return ret


    @staticmethod

    def HeadingLevel3()->str:
        """
        Headings with specific levels, for use in applications that cannot hierarchically nest their sections and thus 
            cannot determine the level of a heading from its level of nesting.
        """
        #GetDllLibPdf().PdfStandardStructTypes_HeadingLevel3.argtypes=[]
        GetDllLibPdf().PdfStandardStructTypes_HeadingLevel3.restype=c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfStandardStructTypes_HeadingLevel3,))
        return ret


    @staticmethod

    def HeadingLevel4()->str:
        """
        Headings with specific levels, for use in applications that cannot hierarchically nest their sections and thus 
            cannot determine the level of a heading from its level of nesting.
        """
        #GetDllLibPdf().PdfStandardStructTypes_HeadingLevel4.argtypes=[]
        GetDllLibPdf().PdfStandardStructTypes_HeadingLevel4.restype=c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfStandardStructTypes_HeadingLevel4,))
        return ret


    @staticmethod

    def HeadingLevel5()->str:
        """
        Headings with specific levels, for use in applications that cannot hierarchically nest their sections and thus 
            cannot determine the level of a heading from its level of nesting.
        """
        #GetDllLibPdf().PdfStandardStructTypes_HeadingLevel5.argtypes=[]
        GetDllLibPdf().PdfStandardStructTypes_HeadingLevel5.restype=c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfStandardStructTypes_HeadingLevel5,))
        return ret


    @staticmethod

    def HeadingLevel6()->str:
        """

        """
        #GetDllLibPdf().PdfStandardStructTypes_HeadingLevel6.argtypes=[]
        GetDllLibPdf().PdfStandardStructTypes_HeadingLevel6.restype=c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfStandardStructTypes_HeadingLevel6,))
        return ret


    @staticmethod

    def Paragraph()->str:
        """
        A low-level division of text.
        """
        #GetDllLibPdf().PdfStandardStructTypes_Paragraph.argtypes=[]
        GetDllLibPdf().PdfStandardStructTypes_Paragraph.restype=c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfStandardStructTypes_Paragraph,))
        return ret


    @staticmethod

    def List()->str:
        """
        A sequence of items of like meaning and importance. Its immediate children should be an optional caption 
            (structure type Caption) followed by one or more list items (structure type LI).
        """
        #GetDllLibPdf().PdfStandardStructTypes_List.argtypes=[]
        GetDllLibPdf().PdfStandardStructTypes_List.restype=c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfStandardStructTypes_List,))
        return ret


    @staticmethod

    def ListItem()->str:
        """
        An individual member of a list. Its children may be one or more labels, list bodies, or both (structure types Lbl or LBody).
        """
        #GetDllLibPdf().PdfStandardStructTypes_ListItem.argtypes=[]
        GetDllLibPdf().PdfStandardStructTypes_ListItem.restype=c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfStandardStructTypes_ListItem,))
        return ret


    @staticmethod

    def Label()->str:
        """
        A name or number that distinguishes a given item from others in the same list or other group of like items. In a dictionary list, 
            for example, it contains the term being defined; in a bulleted or numbered list, it contains the bullet character or the number of the list item and associated punctuation.
        """
        #GetDllLibPdf().PdfStandardStructTypes_Label.argtypes=[]
        GetDllLibPdf().PdfStandardStructTypes_Label.restype=c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfStandardStructTypes_Label,))
        return ret


    @staticmethod

    def ListBody()->str:
        """
        The descriptive content of a list item. In a dictionary list, for example, it contains the definition of the term. It can either contain the content directly or have other BLSEs, 
            perhaps including nested lists, as children.
        """
        #GetDllLibPdf().PdfStandardStructTypes_ListBody.argtypes=[]
        GetDllLibPdf().PdfStandardStructTypes_ListBody.restype=c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfStandardStructTypes_ListBody,))
        return ret


    @staticmethod

    def Table()->str:
        """
        A two-dimensional layout of rectangular data cells, possibly having a complex substructure. It contains either one or more table rows (structure type TR) as children; 
            or an optional table head (structure type THead) followed by one or more table body elements (structure type TBody) and an optional table footer (structure type TFoot). 
            In addition, a table may have an optional caption (structure type Caption; see “Grouping Elements” on page 899) as its first or last child.
        """
        #GetDllLibPdf().PdfStandardStructTypes_Table.argtypes=[]
        GetDllLibPdf().PdfStandardStructTypes_Table.restype=c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfStandardStructTypes_Table,))
        return ret


    @staticmethod

    def TableRow()->str:
        """
        A row of headings or data in a table. It may contain table header cells and table data cells (structure types TH and TD).
        """
        #GetDllLibPdf().PdfStandardStructTypes_TableRow.argtypes=[]
        GetDllLibPdf().PdfStandardStructTypes_TableRow.restype=c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfStandardStructTypes_TableRow,))
        return ret


    @staticmethod

    def TableHeaderCell()->str:
        """
        A table cell containing header text describing one or more rows or columns of the table.
        """
        #GetDllLibPdf().PdfStandardStructTypes_TableHeaderCell.argtypes=[]
        GetDllLibPdf().PdfStandardStructTypes_TableHeaderCell.restype=c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfStandardStructTypes_TableHeaderCell,))
        return ret


    @staticmethod

    def TableDataCell()->str:
        """
        A table cell containing data that is part of the table’s content.
        """
        #GetDllLibPdf().PdfStandardStructTypes_TableDataCell.argtypes=[]
        GetDllLibPdf().PdfStandardStructTypes_TableDataCell.restype=c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfStandardStructTypes_TableDataCell,))
        return ret


    @staticmethod

    def TableHeader()->str:
        """
        A group of rows that constitute the header of a table. If the table is split across multiple pages, 
            these rows may be redrawn at the top of each table fragment (although there is only one THead element).
        """
        #GetDllLibPdf().PdfStandardStructTypes_TableHeader.argtypes=[]
        GetDllLibPdf().PdfStandardStructTypes_TableHeader.restype=c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfStandardStructTypes_TableHeader,))
        return ret


    @staticmethod

    def TableBody()->str:
        """
        A group of rows that constitute the main body portion of a table. If the table is split across multiple pages, the body area may be broken apart on a row boundary. 
            A table may have multiple TBody elements to allow for the drawing of a border or background for a set of rows.
        """
        #GetDllLibPdf().PdfStandardStructTypes_TableBody.argtypes=[]
        GetDllLibPdf().PdfStandardStructTypes_TableBody.restype=c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfStandardStructTypes_TableBody,))
        return ret


    @staticmethod

    def TableFooter()->str:
        """
        A group of rows that constitute the footer of a table. If the table is split across multiple pages, these rows may be redrawn at the bottom of each table fragment 
            (although there is only one TFoot element.)
        """
        #GetDllLibPdf().PdfStandardStructTypes_TableFooter.argtypes=[]
        GetDllLibPdf().PdfStandardStructTypes_TableFooter.restype=c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfStandardStructTypes_TableFooter,))
        return ret


    @staticmethod

    def Span()->str:
        """
        generic inline portion of text having no particular inherent characteristics. 
            It can be used, for example, to delimit a range of text with a given set of styling attributes.
        """
        #GetDllLibPdf().PdfStandardStructTypes_Span.argtypes=[]
        GetDllLibPdf().PdfStandardStructTypes_Span.restype=c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfStandardStructTypes_Span,))
        return ret


    @staticmethod

    def Quotation()->str:
        """
        An inline portion of text attributed to someone other than the author of the surrounding text.
        """
        #GetDllLibPdf().PdfStandardStructTypes_Quotation.argtypes=[]
        GetDllLibPdf().PdfStandardStructTypes_Quotation.restype=c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfStandardStructTypes_Quotation,))
        return ret


    @staticmethod

    def Note()->str:
        """
        An item of explanatory text, such as a footnote or an endnote, that is referred to from within the body of the document.
        """
        #GetDllLibPdf().PdfStandardStructTypes_Note.argtypes=[]
        GetDllLibPdf().PdfStandardStructTypes_Note.restype=c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfStandardStructTypes_Note,))
        return ret


    @staticmethod

    def Reference()->str:
        """
        A citation to content elsewhere in the document.
        """
        #GetDllLibPdf().PdfStandardStructTypes_Reference.argtypes=[]
        GetDllLibPdf().PdfStandardStructTypes_Reference.restype=c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfStandardStructTypes_Reference,))
        return ret


    @staticmethod

    def BibEntry()->str:
        """
        A reference identifying the external source of some cited content. It may contain a label (structure type Lbl) as a child.
        """
        #GetDllLibPdf().PdfStandardStructTypes_BibEntry.argtypes=[]
        GetDllLibPdf().PdfStandardStructTypes_BibEntry.restype=c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfStandardStructTypes_BibEntry,))
        return ret


    @staticmethod

    def Code()->str:
        """
        A fragment of computer program text.
        """
        #GetDllLibPdf().PdfStandardStructTypes_Code.argtypes=[]
        GetDllLibPdf().PdfStandardStructTypes_Code.restype=c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfStandardStructTypes_Code,))
        return ret


    @staticmethod

    def Link()->str:
        """
        An association between a portion of the ILSE’s content and a corresponding link annotation or annotations.
            Its children are one or more content items or child ILSEs and one or more object references identifying the associated link annotations.
        """
        #GetDllLibPdf().PdfStandardStructTypes_Link.argtypes=[]
        GetDllLibPdf().PdfStandardStructTypes_Link.restype=c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfStandardStructTypes_Link,))
        return ret


    @staticmethod

    def Annotation()->str:
        """
        An association between a portion of the ILSE’s content and a corresponding PDF annotation.
        """
        #GetDllLibPdf().PdfStandardStructTypes_Annotation.argtypes=[]
        GetDllLibPdf().PdfStandardStructTypes_Annotation.restype=c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfStandardStructTypes_Annotation,))
        return ret


    @staticmethod

    def Ruby()->str:
        """
        A side-note (annotation) written in a smaller text size and placed adjacent to the base text to which it refers. 
            It is used in Japanese and Chinese to describe the pronunciation of unusual words or to describe such items as abbreviations and logos. 
            A Rubyelement may also contain the RB, RT, and RP elements
        """
        #GetDllLibPdf().PdfStandardStructTypes_Ruby.argtypes=[]
        GetDllLibPdf().PdfStandardStructTypes_Ruby.restype=c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfStandardStructTypes_Ruby,))
        return ret


    @staticmethod

    def RB()->str:
        """
        (Ruby base text) The full-size text to which the ruby annotation is applied. 
            RB can contain text, other inline elements, or a mixture of both. It may have the RubyAlign attribute.
        """
        #GetDllLibPdf().PdfStandardStructTypes_RB.argtypes=[]
        GetDllLibPdf().PdfStandardStructTypes_RB.restype=c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfStandardStructTypes_RB,))
        return ret


    @staticmethod

    def RT()->str:
        """
        (Ruby annotation text) The smaller-size text that is placed adjacent to the ruby base text. 
            It can contain text, other inline elements, or a mixture of both. It may have the RubyAlignand RubyPosition attributes.
        """
        #GetDllLibPdf().PdfStandardStructTypes_RT.argtypes=[]
        GetDllLibPdf().PdfStandardStructTypes_RT.restype=c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfStandardStructTypes_RT,))
        return ret


    @staticmethod

    def RP()->str:
        """
        (Ruby punctuation) Punctuation surrounding the ruby annotation text. 
            It us used only when a ruby annotation cannot be properly formatted in a ruby style and instead is formatted as a normal comment, 
            or when it is formatted as a warichu. It contains text (usually a single open or close parenthesis or similar bracketing character).
        """
        #GetDllLibPdf().PdfStandardStructTypes_RP.argtypes=[]
        GetDllLibPdf().PdfStandardStructTypes_RP.restype=c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfStandardStructTypes_RP,))
        return ret


    @staticmethod

    def Warichu()->str:
        """
        A comment or annotation in a smaller text size and formatted onto two smaller lines within the height of the containing text line and 
            placed following (inline) the base text to which it refers. It is used in Japanese for descriptive comments and 
            for ruby annotation text that is too long to be aesthetically formatted as a ruby. A Warichu element may also contain the WT and WP elements.
        """
        #GetDllLibPdf().PdfStandardStructTypes_Warichu.argtypes=[]
        GetDllLibPdf().PdfStandardStructTypes_Warichu.restype=c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfStandardStructTypes_Warichu,))
        return ret


    @staticmethod

    def WT()->str:
        """
        (Warichu text) The smaller-size text of a warichu comment that is formatted into two lines and placed between surrounding WP elements.
        """
        #GetDllLibPdf().PdfStandardStructTypes_WT.argtypes=[]
        GetDllLibPdf().PdfStandardStructTypes_WT.restype=c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfStandardStructTypes_WT,))
        return ret


    @staticmethod

    def WP()->str:
        """
        (Warichu punctuation) The punctuation that surrounds the WT text. It contains text (usually a single open or close parenthesis or similar bracketing character).
        """
        #GetDllLibPdf().PdfStandardStructTypes_WP.argtypes=[]
        GetDllLibPdf().PdfStandardStructTypes_WP.restype=c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfStandardStructTypes_WP,))
        return ret


    @staticmethod

    def Figure()->str:
        """
        An item of graphical content. Its placement may be specified with the Placementlayout attribute.
        """
        #GetDllLibPdf().PdfStandardStructTypes_Figure.argtypes=[]
        GetDllLibPdf().PdfStandardStructTypes_Figure.restype=c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfStandardStructTypes_Figure,))
        return ret


    @staticmethod

    def Form()->str:
        """
        A mathematical formula.
        """
        #GetDllLibPdf().PdfStandardStructTypes_Form.argtypes=[]
        GetDllLibPdf().PdfStandardStructTypes_Form.restype=c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfStandardStructTypes_Form,))
        return ret


    @staticmethod

    def Formula()->str:
        """
        A widget annotation representing an interactive form field.
        """
        #GetDllLibPdf().PdfStandardStructTypes_Formula.argtypes=[]
        GetDllLibPdf().PdfStandardStructTypes_Formula.restype=c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfStandardStructTypes_Formula,))
        return ret


