from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfTextExtractOptions(SpireObject):
    """
    Represents text extraction options
    """
    def __init__(self):
        GetDllLibPdf().PdfTextExtractOptions_CreatePdfTextExtractOptions.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfTextExtractOptions_CreatePdfTextExtractOptions)
        super(PdfTextExtractOptions, self).__init__(intPtr)
    @property
    def IsSimpleExtraction(self) -> bool:
        """
        Gets or sets whether to perform simple text extraction.
        """
        return None

    @IsSimpleExtraction.setter
    def IsSimpleExtraction(self, value: bool):
        """
        Sets whether to perform simple text extraction.
        """
        GetDllLibPdf().PdfTextExtractOptions_set_IsSimpleExtraction.argtypes = [c_void_p, c_bool]
        CallCFunction(GetDllLibPdf().PdfTextExtractOptions_set_IsSimpleExtraction,self.Ptr, value)

    @property
    def IsExtractAllText(self) -> bool:
        """
        Gets or sets whether to extract all text.
        """
        return None

    @IsExtractAllText.setter
    def IsExtractAllText(self, value: bool):
        """
        Sets whether to extract all text.
        """
        GetDllLibPdf().PdfTextExtractOptions_set_IsExtractAllText.argtypes = [c_void_p, c_bool]
        CallCFunction(GetDllLibPdf().PdfTextExtractOptions_set_IsExtractAllText,self.Ptr, value)

    @property
    def IsShowHiddenText(self) -> bool:
        """
        Gets or sets whether to show hidden text.
        """
        return None

    @IsShowHiddenText.setter
    def IsShowHiddenText(self, value: bool):
        """
        Sets whether to show hidden text.
        """
        GetDllLibPdf().PdfTextExtractOptions_set_IsShowHiddenText.argtypes = [c_void_p, c_bool]
        CallCFunction(GetDllLibPdf().PdfTextExtractOptions_set_IsShowHiddenText,self.Ptr, value)

    @property
    def ExtractArea(self) -> bool:
        """
        Gets or sets the extraction area.
        """
        return None

    @ExtractArea.setter
    def ExtractArea(self, value: 'RectangleF'):
        """
        Sets the extraction area.
        """
        GetDllLibPdf().PdfTextExtractOptions_set_ExtractArea.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfTextExtractOptions_set_ExtractArea,self.Ptr, value.Ptr)