from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfTextFragment(SpireObject):
    """
    The class representing a result of searching designated text from PDF page.
    """

    @property
    def Text(self) -> str:
        """
        Gets the text.
        """
        GetDllLibPdf().PdfTextFragment_get_Text.argtypes = [c_void_p]
        GetDllLibPdf().PdfTextFragment_get_Text.restype = c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfTextFragment_get_Text,self.Ptr))
        return ret

    @property
    def LineText(self) -> str:
        """
        Gets all text of the line which covers the target text.
        """
        GetDllLibPdf().PdfTextFragment_get_LineText.argtypes = [c_void_p]
        GetDllLibPdf().PdfTextFragment_get_LineText.restype = c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfTextFragment_get_LineText,self.Ptr))
        return ret

    @property
    def Page(self) -> 'PdfPageBase':
        """
        Gets the page where the text is located.
        """
        GetDllLibPdf().PdfTextFragment_get_Page.argtypes = [c_void_p]
        GetDllLibPdf().PdfTextFragment_get_Page.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfTextFragment_get_Page,self.Ptr)
        ret = None if intPtr == None else PdfPageBase(intPtr)
        return ret

    @property
    def Positions(self) -> List[PointF]:
        """
        Gets the bounds of the searched text of this System.Drawing RectangleF structure.
        """
        GetDllLibPdf().PdfTextFragment_get_Positions.argtypes=[c_void_p]
        GetDllLibPdf().PdfTextFragment_get_Positions.restype=IntPtrArray
        intPtrArray = CallCFunction(GetDllLibPdf().PdfTextFragment_get_Positions,self.Ptr)
        ret = GetObjVectorFromArray(intPtrArray, PointF)
        return ret

    @property
    def Bounds(self) -> List[RectangleF]:
        """
        Gets the bounds of the searched text of this System.Drawing RectangleF structure.
        """
        GetDllLibPdf().PdfTextFragment_get_Bounds.argtypes=[c_void_p]
        GetDllLibPdf().PdfTextFragment_get_Bounds.restype=IntPtrArray
        intPtrArray = CallCFunction(GetDllLibPdf().PdfTextFragment_get_Bounds,self.Ptr)
        ret = GetObjVectorFromArray(intPtrArray, RectangleF)
        return ret

    @property
    def Sizes(self) -> List[SizeF]:
        """
        Gets the bounds of the searched text of this System.Drawing RectangleF structure.
        """
        GetDllLibPdf().PdfTextFragment_get_Sizes.argtypes=[c_void_p]
        GetDllLibPdf().PdfTextFragment_get_Sizes.restype=IntPtrArray
        intPtrArray = CallCFunction(GetDllLibPdf().PdfTextFragment_get_Sizes,self.Ptr)
        ret = GetObjVectorFromArray(intPtrArray, SizeF)
        return ret

    @property
    def TextStates(self) -> List[PdfTextState]:
        """
        Gets the text state.
        """
        GetDllLibPdf().PdfTextFragment_get_PdfTextState.argtypes=[c_void_p]
        GetDllLibPdf().PdfTextFragment_get_PdfTextState.restype=IntPtrArray
        intPtrArray = CallCFunction(GetDllLibPdf().PdfTextFragment_get_PdfTextState,self.Ptr)
        ret = GetObjVectorFromArray(intPtrArray, PdfTextState)
        return ret

    @dispatch
    def HighLight(self):
        """
        Highlight the target text.
        """
        GetDllLibPdf().PdfTextFragment_HighLight.argtypes = [c_void_p]
        CallCFunction(GetDllLibPdf().PdfTextFragment_HighLight,self.Ptr)

    @dispatch
    def HighLight(self, color: Color):
        """
        Highlight the target text.
        :param name="color": The hight light color.
        """
        intPtrcolor: c_void_p = color.Ptr
        GetDllLibPdf().PdfTextFragment_HighLightC.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfTextFragment_HighLightC,self.Ptr, intPtrcolor)