from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfUnidimensionalBarcode(PdfBarcode):
    """
    Represents the Base class for all the Single dimensional barcodes
    """

    @property
    def Font(self) -> 'PdfFontBase':
        """
        Gets or sets the Text font.
        """
        GetDllLibPdf().PdfUnidimensionalBarcode_get_Font.argtypes = [c_void_p]
        GetDllLibPdf().PdfUnidimensionalBarcode_get_Font.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfUnidimensionalBarcode_get_Font,self.Ptr)
        ret = None if intPtr == None else PdfFontBase(intPtr)
        return ret

    @Font.setter
    def Font(self, value: 'PdfFontBase'):
        """
        Sets the Text font.
        """
        GetDllLibPdf().PdfUnidimensionalBarcode_set_Font.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfUnidimensionalBarcode_set_Font,self.Ptr, value.Ptr)

    @property
    def TextDisplayLocation(self) -> 'TextLocation':
        """
        Gets or sets the text display location.
        """
        GetDllLibPdf().PdfUnidimensionalBarcode_get_TextDisplayLocation.argtypes = [c_void_p]
        GetDllLibPdf().PdfUnidimensionalBarcode_get_TextDisplayLocation.restype = c_int
        ret = CallCFunction(GetDllLibPdf().PdfUnidimensionalBarcode_get_TextDisplayLocation,self.Ptr)
        objwrapped = TextLocation(ret)
        return objwrapped

    @TextDisplayLocation.setter
    def TextDisplayLocation(self, value: 'TextLocation'):
        """
        Sets the text display location.
        """
        GetDllLibPdf().PdfUnidimensionalBarcode_set_TextDisplayLocation.argtypes = [c_void_p, c_int]
        CallCFunction(GetDllLibPdf().PdfUnidimensionalBarcode_set_TextDisplayLocation,self.Ptr, value.value)

    @property
    def ShowCheckDigit(self) -> bool:
        """
        Gets or sets a value indicating whether to show the check digit.
        """
        GetDllLibPdf().PdfUnidimensionalBarcode_get_ShowCheckDigit.argtypes = [c_void_p]
        GetDllLibPdf().PdfUnidimensionalBarcode_get_ShowCheckDigit.restype = c_bool
        ret = CallCFunction(GetDllLibPdf().PdfUnidimensionalBarcode_get_ShowCheckDigit,self.Ptr)
        return ret

    @ShowCheckDigit.setter
    def ShowCheckDigit(self, value: bool):
        """
        Sets a value indicating whether to show the check digit.
        """
        GetDllLibPdf().PdfUnidimensionalBarcode_set_ShowCheckDigit.argtypes = [c_void_p, c_bool]
        CallCFunction(GetDllLibPdf().PdfUnidimensionalBarcode_set_ShowCheckDigit,self.Ptr, value)

    @property
    def EnableCheckDigit(self) -> bool:
        """
        Gets or sets a value indicating whether to enable check digit calculation.
        """
        GetDllLibPdf().PdfUnidimensionalBarcode_get_EnableCheckDigit.argtypes = [c_void_p]
        GetDllLibPdf().PdfUnidimensionalBarcode_get_EnableCheckDigit.restype = c_bool
        ret = CallCFunction(GetDllLibPdf().PdfUnidimensionalBarcode_get_EnableCheckDigit,self.Ptr)
        return ret

    @EnableCheckDigit.setter
    def EnableCheckDigit(self, value: bool):
        """
        Sets a value indicating whether to enable check digit calculation.
        """
        GetDllLibPdf().PdfUnidimensionalBarcode_set_EnableCheckDigit.argtypes = [c_void_p, c_bool]
        CallCFunction(GetDllLibPdf().PdfUnidimensionalBarcode_set_EnableCheckDigit,self.Ptr, value)

    @property
    def BarcodeToTextGapHeight(self) -> float:
        """
        Gets or sets the gap between the barcode and the displayed text.
        """
        GetDllLibPdf().PdfUnidimensionalBarcode_get_BarcodeToTextGapHeight.argtypes = [c_void_p]
        GetDllLibPdf().PdfUnidimensionalBarcode_get_BarcodeToTextGapHeight.restype = c_float
        ret = CallCFunction(GetDllLibPdf().PdfUnidimensionalBarcode_get_BarcodeToTextGapHeight,self.Ptr)
        return ret

    @BarcodeToTextGapHeight.setter
    def BarcodeToTextGapHeight(self, value: float):
        """
        Sets the gap between the barcode and the displayed text.
        """
        GetDllLibPdf().PdfUnidimensionalBarcode_set_BarcodeToTextGapHeight.argtypes = [c_void_p, c_float]
        CallCFunction(GetDllLibPdf().PdfUnidimensionalBarcode_set_BarcodeToTextGapHeight,self.Ptr, value)

    @property
    def TextAlignment(self) -> 'PdfBarcodeTextAlignment':
        """
        Gets or sets the alignment of the text displayed on the barcode.
        """
        GetDllLibPdf().PdfUnidimensionalBarcode_get_TextAlignment.argtypes = [c_void_p]
        GetDllLibPdf().PdfUnidimensionalBarcode_get_TextAlignment.restype = c_int
        ret = CallCFunction(GetDllLibPdf().PdfUnidimensionalBarcode_get_TextAlignment,self.Ptr)
        objwrapped = PdfBarcodeTextAlignment(ret)
        return objwrapped

    @TextAlignment.setter
    def TextAlignment(self, value: 'PdfBarcodeTextAlignment'):
        """
        Sets the alignment of the text displayed on the barcode.
        """
        GetDllLibPdf().PdfUnidimensionalBarcode_set_TextAlignment.argtypes = [c_void_p, c_int]
        CallCFunction(GetDllLibPdf().PdfUnidimensionalBarcode_set_TextAlignment,self.Ptr, value.value)

    @property
    def EncodeStartStopSymbols(self) -> bool:
        """
        Gets or sets a value indicating whether to encode start and stop symbols.
        """
        GetDllLibPdf().PdfUnidimensionalBarcode_get_EncodeStartStopSymbols.argtypes = [c_void_p]
        GetDllLibPdf().PdfUnidimensionalBarcode_get_EncodeStartStopSymbols.restype = c_bool
        ret = CallCFunction(GetDllLibPdf().PdfUnidimensionalBarcode_get_EncodeStartStopSymbols,self.Ptr)
        return ret

    @EncodeStartStopSymbols.setter
    def EncodeStartStopSymbols(self, value: bool):
        """
        Sets a value indicating whether to encode start and stop symbols.
        """
        GetDllLibPdf().PdfUnidimensionalBarcode_set_EncodeStartStopSymbols.argtypes = [c_void_p, c_bool]
        CallCFunction(GetDllLibPdf().PdfUnidimensionalBarcode_set_EncodeStartStopSymbols,self.Ptr, value)

    @dispatch
    def Draw(self, page: PdfPageBase, rect: RectangleF):
        """
        Draws the barcode on the page at the specified region.
        """
        intPtrpage: c_void_p = page.Ptr
        intPtrrect: c_void_p = rect.Ptr

        GetDllLibPdf().PdfUnidimensionalBarcode_Draw.argtypes = [c_void_p, c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfUnidimensionalBarcode_Draw,self.Ptr, intPtrpage, intPtrrect)

    @dispatch
    def Draw(self, page: PdfPageBase, location: PointF):
        """
        Draws the barcode on the page at the specified location.
        """
        intPtrpage: c_void_p = page.Ptr
        intPtrlocation: c_void_p = location.Ptr

        GetDllLibPdf().PdfUnidimensionalBarcode_DrawPL.argtypes = [c_void_p, c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfUnidimensionalBarcode_DrawPL,self.Ptr, intPtrpage, intPtrlocation)

    def ToImage(self) -> 'Image':
        """
        Exports the barcode as image.
        """
        GetDllLibPdf().PdfUnidimensionalBarcode_ToImage.argtypes = [c_void_p]
        GetDllLibPdf().PdfUnidimensionalBarcode_ToImage.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfUnidimensionalBarcode_ToImage,self.Ptr)
        ret = None if intPtr == None else Image(intPtr)
        return ret