from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class XfaChoiceListField(XfaField):
    """
    Represents a choice list field in an XFA form.
    """

    @property
    def IsMultiSelect(self) -> bool:
        """
        Gets a value indicating whether the choice list field allows multiple selections.
        :return: True if the choice list field allows multiple selections, False otherwise.
        """
        GetDllLibPdf().XfaChoiceListField_get_IsMultiSelect.argtypes = [c_void_p]
        GetDllLibPdf().XfaChoiceListField_get_IsMultiSelect.restype = c_bool
        ret = CallCFunction(GetDllLibPdf().XfaChoiceListField_get_IsMultiSelect,self.Ptr)
        return ret

    def GetEvents(self) -> str:
        """
        Gets the events associated with the choice list field.
        :return: The events associated with the choice list field.
        """
        GetDllLibPdf().XfaChoiceListField_GetEvents.argtypes = [c_void_p]
        GetDllLibPdf().XfaChoiceListField_GetEvents.restype = c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().XfaChoiceListField_GetEvents,self.Ptr))
        return ret

    @property
    def SelectedItem(self) -> str:
        """
        Gets the selected item in the choice list field.
        :return: The selected item in the choice list field.
        """
        GetDllLibPdf().XfaChoiceListField_get_SelectedItem.argtypes = [c_void_p]
        GetDllLibPdf().XfaChoiceListField_get_SelectedItem.restype = c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().XfaChoiceListField_get_SelectedItem,self.Ptr))
        return ret

    @SelectedItem.setter
    def SelectedItem(self, value: str):
        """
        Sets the selected item in the choice list field.
        :param value: The selected item to set.
        """
        GetDllLibPdf().XfaChoiceListField_set_SelectedItem.argtypes = [c_void_p, c_wchar_p]
        CallCFunction(GetDllLibPdf().XfaChoiceListField_set_SelectedItem,self.Ptr, value)